module Emoji exposing (..)


type alias Emoji =
    { name : String
    , unicode : String
    , tags : List String
    , x : Int
    , y : Int
    }


type alias Emojis =
    { people : List Emoji
    , nature : List Emoji
    , objects : List Emoji
    , places : List Emoji
    , symbols : List Emoji
    }


type Category
    = Recent
    | People
    | Nature
    | Objects
    | Places
    | Symbols


categories : List Category
categories =
    [ Recent, People, Nature, Objects, Places, Symbols ]


categoryEmoji : Category -> Emoji
categoryEmoji category =
    case category of
        Recent ->
            { name = "clock9", unicode = "🕘", tags = [], x = 460, y = 736 }

        People ->
            { name = "grinning", unicode = "😀", tags = [ "smile", "happy" ], x = 1104, y = 552 }

        Nature ->
            { name = "dog", unicode = "🐶", tags = [ "pet" ], x = 644, y = 874 }

        Objects ->
            { name = "soccer", unicode = "⚽️", tags = [ "sports" ], x = 1426, y = 1564 }

        Places ->
            { name = "car", unicode = "🚗", tags = [], x = 322, y = 644 }

        Symbols ->
            { name = "heart", unicode = "❤️", tags = [ "love" ], x = 828, y = 1104 }


getEmojis : Category -> List Emoji
getEmojis category =
    case category of
        Recent ->
            []

        People ->
            emojis.people

        Nature ->
            emojis.nature

        Objects ->
            emojis.objects

        Places ->
            emojis.places

        Symbols ->
            emojis.symbols


emojis : Emojis
emojis =
    { people =
        [ { name = "grinning", unicode = "😀", tags = [ "smile", "happy" ], x = 1104, y = 552 }
        , { name = "smiley", unicode = "😃", tags = [ "happy", "joy", "haha" ], x = 782, y = 1564 }
        , { name = "smile", unicode = "😄", tags = [ "happy", "joy", "laugh", "pleased" ], x = 690, y = 1564 }
        , { name = "grin", unicode = "😁", tags = [], x = 1104, y = 506 }
        , { name = "laughing", unicode = "😆", tags = [ "happy", "haha" ], x = 1242, y = 46 }
        , { name = "sweat_smile", unicode = "😅", tags = [ "hot" ], x = 1656, y = 0 }
        , { name = "joy", unicode = "😂", tags = [ "tears" ], x = 1196, y = 782 }
        , { name = "rofl", unicode = "🤣", tags = [ "lol", "laughing" ], x = 1518, y = 1196 }
        , { name = "relaxed", unicode = "☺️", tags = [ "blush", "pleased" ], x = 1518, y = 276 }
        , { name = "blush", unicode = "😊", tags = [ "proud" ], x = 552, y = 322 }
        , { name = "innocent", unicode = "😇", tags = [ "angel" ], x = 1104, y = 1150 }
        , { name = "slightly_smiling_face", unicode = "🙂", tags = [], x = 276, y = 1564 }
        , { name = "upside_down_face", unicode = "🙃", tags = [], x = 1702, y = 1610 }
        , { name = "wink", unicode = "😉", tags = [ "flirt" ], x = 1748, y = 874 }
        , { name = "relieved", unicode = "😌", tags = [ "whew" ], x = 1518, y = 322 }
        , { name = "heart_eyes", unicode = "😍", tags = [ "love", "crush" ], x = 920, y = 1104 }
        , { name = "kissing_heart", unicode = "😘", tags = [ "flirt" ], x = 368, y = 1196 }
        , { name = "kissing", unicode = "😗", tags = [], x = 230, y = 1196 }
        , { name = "kissing_smiling_eyes", unicode = "😙", tags = [], x = 414, y = 1196 }
        , { name = "kissing_closed_eyes", unicode = "😚", tags = [], x = 322, y = 1196 }
        , { name = "yum", unicode = "😋", tags = [ "tongue", "lick" ], x = 920, y = 1748 }
        , { name = "stuck_out_tongue_winking_eye", unicode = "😜", tags = [ "prank", "silly" ], x = 598, y = 1610 }
        , { name = "stuck_out_tongue_closed_eyes", unicode = "😝", tags = [ "prank" ], x = 552, y = 1610 }
        , { name = "stuck_out_tongue", unicode = "😛", tags = [], x = 506, y = 1610 }
        , { name = "money_mouth_face", unicode = "🤑", tags = [ "rich" ], x = 1334, y = 184 }
        , { name = "hugs", unicode = "🤗", tags = [], x = 276, y = 1150 }
        , { name = "nerd_face", unicode = "🤓", tags = [ "geek", "glasses" ], x = 1058, y = 1334 }
        , { name = "sunglasses", unicode = "😎", tags = [ "cool" ], x = 1012, y = 1610 }
        , { name = "clown_face", unicode = "🤡", tags = [], x = 782, y = 138 }
        , { name = "cowboy_hat_face", unicode = "🤠", tags = [], x = 828, y = 644 }
        , { name = "smirk", unicode = "😏", tags = [ "smug" ], x = 920, y = 1564 }
        , { name = "unamused", unicode = "😒", tags = [ "meh" ], x = 1702, y = 1334 }
        , { name = "disappointed", unicode = "😞", tags = [ "sad" ], x = 368, y = 874 }
        , { name = "pensive", unicode = "😔", tags = [], x = 414, y = 1426 }
        , { name = "worried", unicode = "😟", tags = [ "nervous" ], x = 552, y = 1748 }
        , { name = "confused", unicode = "😕", tags = [], x = 92, y = 782 }
        , { name = "slightly_frowning_face", unicode = "🙁", tags = [], x = 230, y = 1564 }
        , { name = "frowning_face", unicode = "☹️", tags = [], x = 1058, y = 736 }
        , { name = "persevere", unicode = "😣", tags = [ "struggling" ], x = 506, y = 1426 }
        , { name = "confounded", unicode = "😖", tags = [], x = 46, y = 782 }
        , { name = "tired_face", unicode = "😫", tags = [ "upset", "whine" ], x = 230, y = 1656 }
        , { name = "weary", unicode = "😩", tags = [ "tired" ], x = 1610, y = 1702 }
        , { name = "triumph", unicode = "😤", tags = [ "smug" ], x = 1288, y = 1656 }
        , { name = "angry", unicode = "😠", tags = [ "mad", "annoyed" ], x = 0, y = 230 }
        , { name = "rage", unicode = "😡", tags = [ "angry" ], x = 690, y = 1472 }
        , { name = "no_mouth", unicode = "😶", tags = [ "mute", "silence" ], x = 1380, y = 966 }
        , { name = "neutral_face", unicode = "😐", tags = [ "meh" ], x = 1150, y = 1334 }
        , { name = "expressionless", unicode = "😑", tags = [], x = 966, y = 276 }
        , { name = "hushed", unicode = "😯", tags = [ "silence", "speechless" ], x = 414, y = 1150 }
        , { name = "frowning", unicode = "😦", tags = [], x = 1058, y = 690 }
        , { name = "anguished", unicode = "😧", tags = [ "stunned" ], x = 92, y = 230 }
        , { name = "open_mouth", unicode = "😮", tags = [ "surprise", "impressed", "wow" ], x = 1380, y = 1380 }
        , { name = "astonished", unicode = "😲", tags = [ "amazed", "gasp" ], x = 368, y = 92 }
        , { name = "dizzy_face", unicode = "😵", tags = [], x = 506, y = 874 }
        , { name = "flushed", unicode = "😳", tags = [], x = 782, y = 1012 }
        , { name = "scream", unicode = "😱", tags = [ "horror", "shocked" ], x = 1426, y = 1518 }
        , { name = "fearful", unicode = "😨", tags = [ "scared", "shocked", "oops" ], x = 1012, y = 138 }
        , { name = "cold_sweat", unicode = "😰", tags = [ "nervous" ], x = 782, y = 460 }
        , { name = "cry", unicode = "😢", tags = [ "sad", "tear" ], x = 414, y = 828 }
        , { name = "disappointed_relieved", unicode = "😥", tags = [ "phew", "sweat", "nervous" ], x = 414, y = 874 }
        , { name = "drooling_face", unicode = "🤤", tags = [], x = 920, y = 368 }
        , { name = "sob", unicode = "😭", tags = [ "sad", "cry", "bawling" ], x = 1380, y = 1564 }
        , { name = "sweat", unicode = "😓", tags = [], x = 1564, y = 1610 }
        , { name = "sleepy", unicode = "😪", tags = [ "tired" ], x = 184, y = 1564 }
        , { name = "sleeping", unicode = "😴", tags = [ "zzz" ], x = 92, y = 1564 }
        , { name = "roll_eyes", unicode = "🙄", tags = [], x = 1518, y = 1242 }
        , { name = "thinking", unicode = "🤔", tags = [], x = 1656, y = 1288 }
        , { name = "lying_face", unicode = "🤥", tags = [ "liar" ], x = 322, y = 1242 }
        , { name = "grimacing", unicode = "😬", tags = [], x = 1104, y = 460 }
        , { name = "zipper_mouth_face", unicode = "🤐", tags = [ "silence", "hush" ], x = 1150, y = 1748 }
        , { name = "nauseated_face", unicode = "🤢", tags = [ "sick", "barf", "disgusted" ], x = 828, y = 1334 }
        , { name = "sneezing_face", unicode = "🤧", tags = [ "achoo", "sick" ], x = 1150, y = 1564 }
        , { name = "mask", unicode = "😷", tags = [ "sick", "ill" ], x = 138, y = 1288 }
        , { name = "face_with_thermometer", unicode = "🤒", tags = [ "sick" ], x = 966, y = 552 }
        , { name = "face_with_head_bandage", unicode = "🤕", tags = [ "hurt" ], x = 966, y = 506 }
        , { name = "smiling_imp", unicode = "😈", tags = [ "devil", "evil", "horns" ], x = 874, y = 1564 }
        , { name = "imp", unicode = "👿", tags = [ "angry", "devil", "evil", "horns" ], x = 782, y = 1150 }
        , { name = "japanese_ogre", unicode = "👹", tags = [ "monster" ], x = 1196, y = 598 }
        , { name = "japanese_goblin", unicode = "👺", tags = [], x = 1196, y = 552 }
        , { name = "hankey", unicode = "💩", tags = [ "crap" ], x = 552, y = 1104 }
        , { name = "ghost", unicode = "👻", tags = [ "halloween" ], x = 460, y = 1058 }
        , { name = "skull", unicode = "💀", tags = [ "dead", "danger", "poison" ], x = 0, y = 1564 }
        , { name = "skull_and_crossbones", unicode = "☠️", tags = [ "danger", "pirate" ], x = 46, y = 1564 }
        , { name = "alien", unicode = "👽", tags = [ "ufo" ], x = 46, y = 184 }
        , { name = "space_invader", unicode = "👾", tags = [ "game", "retro" ], x = 1610, y = 230 }
        , { name = "robot", unicode = "🤖", tags = [], x = 1518, y = 1104 }
        , { name = "jack_o_lantern", unicode = "🎃", tags = [ "halloween" ], x = 1196, y = 368 }
        , { name = "smiley_cat", unicode = "😺", tags = [], x = 828, y = 1564 }
        , { name = "smile_cat", unicode = "😸", tags = [], x = 736, y = 1564 }
        , { name = "joy_cat", unicode = "😹", tags = [], x = 1196, y = 828 }
        , { name = "heart_eyes_cat", unicode = "😻", tags = [], x = 966, y = 1104 }
        , { name = "smirk_cat", unicode = "😼", tags = [], x = 966, y = 1564 }
        , { name = "kissing_cat", unicode = "😽", tags = [], x = 276, y = 1196 }
        , { name = "scream_cat", unicode = "🙀", tags = [ "horror" ], x = 1472, y = 1518 }
        , { name = "crying_cat_face", unicode = "😿", tags = [ "sad", "tear" ], x = 460, y = 828 }
        , { name = "pouting_cat", unicode = "😾", tags = [], x = 1472, y = 1012 }
        , { name = "open_hands", unicode = "👐", tags = [], x = 1334, y = 1380 }
        , { name = "raised_hands", unicode = "🙌", tags = [ "hooray" ], x = 1242, y = 1472 }
        , { name = "clap", unicode = "👏", tags = [ "praise", "applause" ], x = 690, y = 690 }
        , { name = "pray", unicode = "🙏", tags = [ "please", "hope", "wish" ], x = 1472, y = 1150 }
        , { name = "handshake", unicode = "🤝", tags = [ "deal" ], x = 506, y = 1104 }
        , { name = "+1", unicode = "👍", tags = [ "approve", "ok" ], x = 46, y = 0 }
        , { name = "-1", unicode = "👎", tags = [ "disapprove", "bury" ], x = 414, y = 1288 }
        , { name = "fist_oncoming", unicode = "👊", tags = [ "attack" ], x = 230, y = 1012 }
        , { name = "fist_raised", unicode = "✊", tags = [ "power" ], x = 276, y = 1012 }
        , { name = "fist_left", unicode = "🤛", tags = [], x = 184, y = 1012 }
        , { name = "fist_right", unicode = "🤜", tags = [], x = 322, y = 1012 }
        , { name = "crossed_fingers", unicode = "🤞", tags = [ "luck", "hopeful" ], x = 230, y = 828 }
        , { name = "v", unicode = "✌️", tags = [ "victory", "peace" ], x = 138, y = 1702 }
        , { name = "metal", unicode = "🤘", tags = [], x = 874, y = 1288 }
        , { name = "ok_hand", unicode = "👌", tags = [], x = 598, y = 1380 }
        , { name = "point_left", unicode = "👈", tags = [], x = 1472, y = 46 }
        , { name = "point_right", unicode = "👉", tags = [], x = 1472, y = 92 }
        , { name = "point_up_2", unicode = "👆", tags = [], x = 1472, y = 184 }
        , { name = "point_down", unicode = "👇", tags = [], x = 1472, y = 0 }
        , { name = "point_up", unicode = "☝️", tags = [], x = 1472, y = 138 }
        , { name = "hand", unicode = "✋", tags = [ "highfive", "stop" ], x = 414, y = 1104 }
        , { name = "raised_back_of_hand", unicode = "🤚", tags = [], x = 1104, y = 1472 }
        , { name = "raised_hand_with_fingers_splayed", unicode = "🖐", tags = [], x = 1196, y = 1472 }
        , { name = "vulcan_salute", unicode = "🖖", tags = [ "prosper", "spock" ], x = 828, y = 1702 }
        , { name = "wave", unicode = "👋", tags = [ "goodbye" ], x = 1380, y = 1702 }
        , { name = "call_me_hand", unicode = "🤙", tags = [], x = 644, y = 184 }
        , { name = "muscle", unicode = "💪", tags = [ "flex", "bicep", "strong", "workout" ], x = 276, y = 1334 }
        , { name = "middle_finger", unicode = "🖕", tags = [], x = 1150, y = 1288 }
        , { name = "writing_hand", unicode = "✍️", tags = [], x = 644, y = 1748 }
        , { name = "selfie", unicode = "🤳", tags = [], x = 1564, y = 184 }
        , { name = "nail_care", unicode = "💅", tags = [ "beauty", "manicure" ], x = 598, y = 1334 }
        , { name = "ring", unicode = "💍", tags = [ "wedding", "marriage", "engaged" ], x = 1518, y = 1058 }
        , { name = "lipstick", unicode = "💄", tags = [ "makeup" ], x = 1242, y = 966 }
        , { name = "kiss", unicode = "💋", tags = [ "lipstick" ], x = 184, y = 1196 }
        , { name = "lips", unicode = "👄", tags = [ "kiss" ], x = 1242, y = 920 }
        , { name = "tongue", unicode = "👅", tags = [ "taste" ], x = 598, y = 1656 }
        , { name = "ear", unicode = "👂", tags = [ "hear", "sound", "listen" ], x = 920, y = 690 }
        , { name = "nose", unicode = "👃", tags = [ "smell" ], x = 1380, y = 1334 }
        , { name = "footprints", unicode = "👣", tags = [ "feet", "tracks" ], x = 966, y = 1012 }
        , { name = "eye", unicode = "👁", tags = [], x = 966, y = 322 }
        , { name = "eyes", unicode = "👀", tags = [ "look", "see", "watch" ], x = 966, y = 460 }
        , { name = "speaking_head", unicode = "🗣", tags = [], x = 1610, y = 644 }
        , { name = "bust_in_silhouette", unicode = "👤", tags = [ "user" ], x = 552, y = 598 }
        , { name = "busts_in_silhouette", unicode = "👥", tags = [ "users", "group", "team" ], x = 598, y = 598 }
        , { name = "baby", unicode = "👶", tags = [ "child", "newborn" ], x = 184, y = 368 }
        , { name = "boy", unicode = "👦", tags = [ "child" ], x = 598, y = 138 }
        , { name = "girl", unicode = "👧", tags = [ "child" ], x = 644, y = 1058 }
        , { name = "man", unicode = "👨", tags = [ "mustache", "father", "dad" ], x = 1150, y = 1242 }
        , { name = "woman", unicode = "👩", tags = [ "girls" ], x = 1748, y = 966 }
        , { name = "blonde_woman", unicode = "👱\u{200D}♀️️", tags = [], x = 552, y = 46 }
        , { name = "blonde_woman", unicode = "👱\u{200D}♀️", tags = [], x = 552, y = 46 }
        , { name = "blonde_man", unicode = "👱", tags = [ "boy" ], x = 552, y = 0 }
        , { name = "older_man", unicode = "👴", tags = [], x = 782, y = 1380 }
        , { name = "older_woman", unicode = "👵", tags = [], x = 828, y = 1380 }
        , { name = "man_with_gua_pi_mao", unicode = "👲", tags = [], x = 1288, y = 1012 }
        , { name = "woman_with_turban", unicode = "👳\u{200D}♀️", tags = [], x = 276, y = 1748 }
        , { name = "man_with_turban", unicode = "👳", tags = [], x = 1288, y = 1058 }
        , { name = "policewoman", unicode = "👮\u{200D}♀️", tags = [], x = 1472, y = 368 }
        , { name = "policeman", unicode = "👮", tags = [ "police", "law" ], x = 1472, y = 322 }
        , { name = "construction_worker_woman", unicode = "👷\u{200D}♀️", tags = [], x = 414, y = 782 }
        , { name = "construction_worker_man", unicode = "👷", tags = [ "helmet" ], x = 368, y = 782 }
        , { name = "guardswoman", unicode = "💂\u{200D}♀️", tags = [], x = 1104, y = 736 }
        , { name = "guardsman", unicode = "💂", tags = [], x = 1104, y = 690 }
        , { name = "female_detective", unicode = "🕵️\u{200D}♀️️", tags = [ "sleuth" ], x = 1012, y = 276 }
        , { name = "male_detective", unicode = "🕵", tags = [ "sleuth" ], x = 1012, y = 1242 }
        , { name = "woman_health_worker", unicode = "👩\u{200D}⚕️", tags = [ "doctor", "nurse" ], x = 1748, y = 1380 }
        , { name = "man_health_worker", unicode = "👨\u{200D}⚕️", tags = [ "doctor", "nurse" ], x = 1288, y = 322 }
        , { name = "woman_farmer", unicode = "👩\u{200D}🌾️", tags = [], x = 1748, y = 1288 }
        , { name = "man_farmer", unicode = "👨\u{200D}🌾️", tags = [], x = 1288, y = 230 }
        , { name = "woman_cook", unicode = "👩\u{200D}🍳️", tags = [ "chef" ], x = 1748, y = 1150 }
        , { name = "man_cook", unicode = "👨\u{200D}🍳️", tags = [ "chef" ], x = 1288, y = 46 }
        , { name = "woman_student", unicode = "👩\u{200D}🎓️", tags = [ "graduation" ], x = 138, y = 1748 }
        , { name = "man_student", unicode = "👨\u{200D}🎓️", tags = [ "graduation" ], x = 1288, y = 874 }
        , { name = "woman_singer", unicode = "👩\u{200D}🎤️", tags = [ "rockstar" ], x = 92, y = 1748 }
        , { name = "man_singer", unicode = "👨\u{200D}🎤️", tags = [ "rockstar" ], x = 1288, y = 828 }
        , { name = "woman_teacher", unicode = "👩\u{200D}🏫️", tags = [ "school", "professor" ], x = 184, y = 1748 }
        , { name = "man_teacher", unicode = "👨\u{200D}🏫️", tags = [ "school", "professor" ], x = 1288, y = 920 }
        , { name = "woman_factory_worker", unicode = "👩\u{200D}🏭️", tags = [], x = 1748, y = 1242 }
        , { name = "man_factory_worker", unicode = "👨\u{200D}🏭️", tags = [], x = 1288, y = 184 }
        , { name = "woman_technologist", unicode = "👩\u{200D}💻️", tags = [ "coder" ], x = 230, y = 1748 }
        , { name = "man_technologist", unicode = "👨\u{200D}💻️", tags = [ "coder" ], x = 1288, y = 966 }
        , { name = "woman_office_worker", unicode = "👩\u{200D}💼️", tags = [ "business" ], x = 1748, y = 1564 }
        , { name = "man_office_worker", unicode = "👨\u{200D}💼️", tags = [ "business" ], x = 1288, y = 552 }
        , { name = "woman_mechanic", unicode = "👩\u{200D}🔧️", tags = [], x = 1748, y = 1518 }
        , { name = "man_mechanic", unicode = "👨\u{200D}🔧️", tags = [], x = 1288, y = 506 }
        , { name = "woman_scientist", unicode = "👩\u{200D}🔬️", tags = [ "research" ], x = 0, y = 1748 }
        , { name = "man_scientist", unicode = "👨\u{200D}🔬️", tags = [ "research" ], x = 1288, y = 736 }
        , { name = "woman_artist", unicode = "👩\u{200D}🎨️", tags = [ "painter" ], x = 1748, y = 1012 }
        , { name = "man_artist", unicode = "👨\u{200D}🎨️", tags = [ "painter" ], x = 1196, y = 1242 }
        , { name = "woman_firefighter", unicode = "👩\u{200D}🚒️", tags = [], x = 1748, y = 1334 }
        , { name = "man_firefighter", unicode = "👨\u{200D}🚒️", tags = [], x = 1288, y = 276 }
        , { name = "woman_pilot", unicode = "👩\u{200D}✈️", tags = [], x = 1748, y = 1610 }
        , { name = "man_pilot", unicode = "👨\u{200D}✈️", tags = [], x = 1288, y = 598 }
        , { name = "woman_astronaut", unicode = "👩\u{200D}🚀️", tags = [ "space" ], x = 1748, y = 1058 }
        , { name = "man_astronaut", unicode = "👨\u{200D}🚀️", tags = [ "space" ], x = 1242, y = 1242 }
        , { name = "woman_judge", unicode = "👩\u{200D}⚖️", tags = [ "justice" ], x = 1748, y = 1426 }
        , { name = "man_judge", unicode = "👨\u{200D}⚖️", tags = [ "justice" ], x = 1288, y = 414 }
        , { name = "mrs_claus", unicode = "🤶", tags = [ "santa" ], x = 230, y = 1334 }
        , { name = "santa", unicode = "🎅", tags = [ "christmas" ], x = 920, y = 1518 }
        , { name = "princess", unicode = "👸", tags = [ "blonde", "crown", "royal" ], x = 1472, y = 1380 }
        , { name = "prince", unicode = "🤴", tags = [ "crown", "royal" ], x = 1472, y = 1334 }
        , { name = "bride_with_veil", unicode = "👰", tags = [ "marriage", "wedding" ], x = 598, y = 276 }
        , { name = "man_in_tuxedo", unicode = "🤵", tags = [ "groom", "marriage", "wedding" ], x = 1288, y = 368 }
        , { name = "angel", unicode = "👼", tags = [], x = 230, y = 92 }
        , { name = "pregnant_woman", unicode = "🤰", tags = [], x = 1472, y = 1242 }
        , { name = "bowing_woman", unicode = "🙇\u{200D}♀️", tags = [ "respect", "thanks" ], x = 552, y = 552 }
        , { name = "bowing_man", unicode = "🙇", tags = [ "respect", "thanks" ], x = 506, y = 552 }
        , { name = "tipping_hand_woman", unicode = "💁", tags = [], x = 184, y = 1656 }
        , { name = "tipping_hand_man", unicode = "💁\u{200D}♂️", tags = [ "information" ], x = 138, y = 1656 }
        , { name = "no_good_woman", unicode = "🙅", tags = [ "stop", "halt" ], x = 1380, y = 874 }
        , { name = "no_good_man", unicode = "🙅\u{200D}♂️", tags = [ "stop", "halt" ], x = 1380, y = 828 }
        , { name = "ok_woman", unicode = "🙆", tags = [], x = 690, y = 1380 }
        , { name = "ok_man", unicode = "🙆\u{200D}♂️", tags = [], x = 644, y = 1380 }
        , { name = "raising_hand_woman", unicode = "🙋", tags = [], x = 1380, y = 1472 }
        , { name = "raising_hand_man", unicode = "🙋\u{200D}♂️", tags = [], x = 1334, y = 1472 }
        , { name = "woman_facepalming", unicode = "🤦\u{200D}♀️", tags = [], x = 1748, y = 1196 }
        , { name = "man_facepalming", unicode = "🤦\u{200D}♂️", tags = [], x = 1288, y = 138 }
        , { name = "woman_shrugging", unicode = "🤷\u{200D}♀️", tags = [], x = 46, y = 1748 }
        , { name = "man_shrugging", unicode = "🤷\u{200D}♂️", tags = [], x = 1288, y = 782 }
        , { name = "pouting_woman", unicode = "🙎", tags = [], x = 1472, y = 1104 }
        , { name = "pouting_man", unicode = "🙎\u{200D}♂️", tags = [], x = 1472, y = 1058 }
        , { name = "frowning_woman", unicode = "🙍", tags = [ "sad" ], x = 1058, y = 828 }
        , { name = "frowning_man", unicode = "🙍\u{200D}♂️", tags = [], x = 1058, y = 782 }
        , { name = "haircut_woman", unicode = "💇", tags = [ "beauty" ], x = 92, y = 1104 }
        , { name = "haircut_man", unicode = "💇\u{200D}♂️", tags = [], x = 46, y = 1104 }
        , { name = "massage_woman", unicode = "💆", tags = [ "spa" ], x = 276, y = 1288 }
        , { name = "massage_man", unicode = "💆\u{200D}♂️", tags = [ "spa" ], x = 230, y = 1288 }
        , { name = "business_suit_levitating", unicode = "🕴", tags = [], x = 460, y = 598 }
        , { name = "dancer", unicode = "💃", tags = [ "dress" ], x = 874, y = 276 }
        , { name = "man_dancing", unicode = "🕺", tags = [ "dancer" ], x = 1288, y = 92 }
        , { name = "dancing_women", unicode = "👯", tags = [ "bunny" ], x = 874, y = 414 }
        , { name = "dancing_men", unicode = "👯\u{200D}♂️", tags = [ "bunny" ], x = 874, y = 368 }
        , { name = "walking_woman", unicode = "🚶\u{200D}♀️", tags = [], x = 966, y = 1702 }
        , { name = "walking_man", unicode = "🚶", tags = [], x = 920, y = 1702 }
        , { name = "running_woman", unicode = "🏃\u{200D}♀️", tags = [ "exercise", "workout", "marathon" ], x = 506, y = 1518 }
        , { name = "running_man", unicode = "🏃", tags = [ "exercise", "workout", "marathon" ], x = 414, y = 1518 }
        , { name = "couple", unicode = "👫", tags = [ "date" ], x = 828, y = 138 }
        , { name = "two_women_holding_hands", unicode = "👭", tags = [ "couple", "date" ], x = 1702, y = 598 }
        , { name = "two_men_holding_hands", unicode = "👬", tags = [ "couple", "date" ], x = 1702, y = 552 }
        , { name = "couple_with_heart_woman_man", unicode = "💑", tags = [], x = 828, y = 276 }
        , { name = "couple_with_heart_woman_woman", unicode = "👩\u{200D}❤️\u{200D}👩️", tags = [], x = 828, y = 322 }
        , { name = "couple_with_heart_man_man", unicode = "👨\u{200D}❤️\u{200D}👨️", tags = [], x = 828, y = 230 }
        , { name = "couplekiss_man_woman", unicode = "💏", tags = [], x = 828, y = 460 }
        , { name = "couplekiss_woman_woman", unicode = "👩\u{200D}❤️\u{200D}💋\u{200D}👩️", tags = [], x = 828, y = 506 }
        , { name = "couplekiss_man_man", unicode = "👨\u{200D}❤️\u{200D}💋\u{200D}👨️", tags = [], x = 828, y = 414 }
        , { name = "family_man_woman_boy", unicode = "👪", tags = [ "home", "parents", "child" ], x = 322, y = 966 }
        , { name = "family_man_woman_girl", unicode = "👨\u{200D}👩\u{200D}👧️", tags = [], x = 414, y = 966 }
        , { name = "family_man_woman_girl_boy", unicode = "👨\u{200D}👩\u{200D}👧\u{200D}👦️", tags = [], x = 460, y = 966 }
        , { name = "family_man_woman_boy_boy", unicode = "👨\u{200D}👩\u{200D}👦\u{200D}👦️", tags = [], x = 368, y = 966 }
        , { name = "family_man_woman_girl_girl", unicode = "👨\u{200D}👩\u{200D}👧\u{200D}👧️", tags = [], x = 506, y = 966 }
        , { name = "family_woman_woman_boy", unicode = "👩\u{200D}👩\u{200D}👦️", tags = [], x = 782, y = 966 }
        , { name = "family_woman_woman_girl", unicode = "👩\u{200D}👩\u{200D}👧️", tags = [], x = 874, y = 966 }
        , { name = "family_woman_woman_girl_boy", unicode = "👩\u{200D}👩\u{200D}👧\u{200D}👦️", tags = [], x = 920, y = 966 }
        , { name = "family_woman_woman_boy_boy", unicode = "👩\u{200D}👩\u{200D}👦\u{200D}👦️", tags = [], x = 828, y = 966 }
        , { name = "family_woman_woman_girl_girl", unicode = "👩\u{200D}👩\u{200D}👧\u{200D}👧️", tags = [], x = 966, y = 966 }
        , { name = "family_man_man_boy", unicode = "👨\u{200D}👨\u{200D}👦️", tags = [], x = 92, y = 966 }
        , { name = "family_man_man_girl", unicode = "👨\u{200D}👨\u{200D}👧️", tags = [], x = 184, y = 966 }
        , { name = "family_man_man_girl_boy", unicode = "👨\u{200D}👨\u{200D}👧\u{200D}👦️", tags = [], x = 230, y = 966 }
        , { name = "family_man_man_boy_boy", unicode = "👨\u{200D}👨\u{200D}👦\u{200D}👦️", tags = [], x = 138, y = 966 }
        , { name = "family_man_man_girl_girl", unicode = "👨\u{200D}👨\u{200D}👧\u{200D}👧️", tags = [], x = 276, y = 966 }
        , { name = "family_woman_boy", unicode = "👩\u{200D}👦️", tags = [], x = 552, y = 966 }
        , { name = "family_woman_girl", unicode = "👩\u{200D}👧️", tags = [], x = 644, y = 966 }
        , { name = "family_woman_girl_boy", unicode = "👩\u{200D}👧\u{200D}👦️", tags = [], x = 690, y = 966 }
        , { name = "family_woman_boy_boy", unicode = "👩\u{200D}👦\u{200D}👦️", tags = [], x = 598, y = 966 }
        , { name = "family_woman_girl_girl", unicode = "👩\u{200D}👧\u{200D}👧️", tags = [], x = 736, y = 966 }
        , { name = "family_man_boy", unicode = "👨\u{200D}👦️", tags = [], x = 966, y = 828 }
        , { name = "family_man_girl", unicode = "👨\u{200D}👧️", tags = [], x = 966, y = 920 }
        , { name = "family_man_girl_boy", unicode = "👨\u{200D}👧\u{200D}👦️", tags = [], x = 0, y = 966 }
        , { name = "family_man_boy_boy", unicode = "👨\u{200D}👦\u{200D}👦️", tags = [], x = 966, y = 874 }
        , { name = "family_man_girl_girl", unicode = "👨\u{200D}👧\u{200D}👧️", tags = [], x = 46, y = 966 }
        , { name = "womans_clothes", unicode = "👚", tags = [], x = 322, y = 1748 }
        , { name = "shirt", unicode = "👕", tags = [], x = 1564, y = 874 }
        , { name = "jeans", unicode = "👖", tags = [ "pants" ], x = 1196, y = 644 }
        , { name = "necktie", unicode = "👔", tags = [ "shirt", "formal" ], x = 920, y = 1334 }
        , { name = "dress", unicode = "👗", tags = [], x = 920, y = 276 }
        , { name = "bikini", unicode = "👙", tags = [ "beach" ], x = 506, y = 414 }
        , { name = "kimono", unicode = "👘", tags = [], x = 92, y = 1196 }
        , { name = "high_heel", unicode = "👠", tags = [ "shoe" ], x = 1150, y = 552 }
        , { name = "sandal", unicode = "👡", tags = [ "shoe" ], x = 874, y = 1518 }
        , { name = "boot", unicode = "👢", tags = [], x = 230, y = 552 }
        , { name = "mans_shoe", unicode = "👞", tags = [], x = 1288, y = 1150 }
        , { name = "athletic_shoe", unicode = "👟", tags = [ "sneaker", "sport", "running" ], x = 368, y = 138 }
        , { name = "womans_hat", unicode = "👒", tags = [], x = 368, y = 1748 }
        , { name = "tophat", unicode = "🎩", tags = [ "hat", "classy" ], x = 690, y = 1656 }
        , { name = "mortar_board", unicode = "🎓", tags = [ "education", "college", "university", "graduation" ], x = 1334, y = 690 }
        , { name = "crown", unicode = "👑", tags = [ "king", "queen", "royal" ], x = 368, y = 828 }
        , { name = "rescue_worker_helmet", unicode = "⛑", tags = [], x = 1518, y = 506 }
        , { name = "school_satchel", unicode = "🎒", tags = [], x = 1242, y = 1518 }
        , { name = "pouch", unicode = "👝", tags = [ "bag" ], x = 1472, y = 828 }
        , { name = "purse", unicode = "👛", tags = [], x = 138, y = 1472 }
        , { name = "handbag", unicode = "👜", tags = [ "bag" ], x = 460, y = 1104 }
        , { name = "briefcase", unicode = "💼", tags = [ "business" ], x = 598, y = 368 }
        , { name = "eyeglasses", unicode = "👓", tags = [ "glasses" ], x = 966, y = 414 }
        , { name = "dark_sunglasses", unicode = "🕶", tags = [], x = 874, y = 506 }
        , { name = "closed_umbrella", unicode = "🌂", tags = [ "weather", "rain" ], x = 644, y = 736 }
        , { name = "open_umbrella", unicode = "☂️", tags = [], x = 1426, y = 0 }
        ]
    , nature =
        [ { name = "dog", unicode = "🐶", tags = [ "pet" ], x = 644, y = 874 }
        , { name = "cat", unicode = "🐱", tags = [ "pet" ], x = 644, y = 644 }
        , { name = "mouse", unicode = "🐭", tags = [], x = 0, y = 1334 }
        , { name = "hamster", unicode = "🐹", tags = [ "pet" ], x = 368, y = 1104 }
        , { name = "rabbit", unicode = "🐰", tags = [ "bunny" ], x = 368, y = 1472 }
        , { name = "fox_face", unicode = "🦊", tags = [], x = 1058, y = 184 }
        , { name = "bear", unicode = "🐻", tags = [], x = 0, y = 460 }
        , { name = "panda_face", unicode = "🐼", tags = [], x = 1426, y = 874 }
        , { name = "koala", unicode = "🐨", tags = [], x = 552, y = 1196 }
        , { name = "tiger", unicode = "🐯", tags = [], x = 1656, y = 1610 }
        , { name = "lion", unicode = "🦁", tags = [], x = 1242, y = 874 }
        , { name = "cow", unicode = "🐮", tags = [], x = 828, y = 552 }
        , { name = "pig", unicode = "🐷", tags = [], x = 920, y = 1426 }
        , { name = "pig_nose", unicode = "🐽", tags = [], x = 1012, y = 1426 }
        , { name = "frog", unicode = "🐸", tags = [], x = 1058, y = 644 }
        , { name = "monkey_face", unicode = "🐵", tags = [], x = 1334, y = 414 }
        , { name = "see_no_evil", unicode = "🙈", tags = [ "monkey", "blind", "ignore" ], x = 1564, y = 92 }
        , { name = "hear_no_evil", unicode = "🙉", tags = [ "monkey", "deaf" ], x = 782, y = 1104 }
        , { name = "speak_no_evil", unicode = "🙊", tags = [ "monkey", "mute", "hush" ], x = 1610, y = 552 }
        , { name = "monkey", unicode = "🐒", tags = [], x = 1334, y = 368 }
        , { name = "chicken", unicode = "🐔", tags = [], x = 0, y = 690 }
        , { name = "penguin", unicode = "🐧", tags = [], x = 368, y = 1426 }
        , { name = "bird", unicode = "🐦", tags = [], x = 0, y = 506 }
        , { name = "baby_chick", unicode = "🐤", tags = [], x = 276, y = 368 }
        , { name = "hatching_chick", unicode = "🐣", tags = [], x = 690, y = 1104 }
        , { name = "hatched_chick", unicode = "🐥", tags = [], x = 644, y = 1104 }
        , { name = "duck", unicode = "🦆", tags = [], x = 920, y = 506 }
        , { name = "eagle", unicode = "🦅", tags = [], x = 920, y = 644 }
        , { name = "owl", unicode = "🦉", tags = [], x = 1426, y = 276 }
        , { name = "bat", unicode = "🦇", tags = [], x = 460, y = 230 }
        , { name = "wolf", unicode = "🐺", tags = [], x = 1748, y = 920 }
        , { name = "boar", unicode = "🐗", tags = [], x = 552, y = 368 }
        , { name = "horse", unicode = "🐴", tags = [], x = 1150, y = 874 }
        , { name = "unicorn", unicode = "🦄", tags = [], x = 1702, y = 1426 }
        , { name = "bee", unicode = "🐝", tags = [], x = 92, y = 460 }
        , { name = "bug", unicode = "🐛", tags = [], x = 0, y = 598 }
        , { name = "butterfly", unicode = "🦋", tags = [], x = 644, y = 0 }
        , { name = "snail", unicode = "🐌", tags = [ "slow" ], x = 1058, y = 1564 }
        , { name = "shell", unicode = "🐚", tags = [ "sea", "beach" ], x = 1564, y = 644 }
        , { name = "beetle", unicode = "🐞", tags = [ "bug" ], x = 230, y = 460 }
        , { name = "ant", unicode = "🐜", tags = [], x = 138, y = 230 }
        , { name = "spider", unicode = "🕷", tags = [], x = 1610, y = 782 }
        , { name = "spider_web", unicode = "🕸", tags = [], x = 1610, y = 828 }
        , { name = "turtle", unicode = "🐢", tags = [ "slow" ], x = 1702, y = 276 }
        , { name = "snake", unicode = "🐍", tags = [], x = 1104, y = 1564 }
        , { name = "lizard", unicode = "🦎", tags = [], x = 1242, y = 1058 }
        , { name = "scorpion", unicode = "🦂", tags = [], x = 1334, y = 1518 }
        , { name = "crab", unicode = "🦀", tags = [], x = 828, y = 690 }
        , { name = "squid", unicode = "🦑", tags = [], x = 1610, y = 1012 }
        , { name = "octopus", unicode = "🐙", tags = [], x = 368, y = 1380 }
        , { name = "shrimp", unicode = "🦐", tags = [], x = 1564, y = 1150 }
        , { name = "tropical_fish", unicode = "🐠", tags = [], x = 1518, y = 1656 }
        , { name = "fish", unicode = "🐟", tags = [], x = 0, y = 1012 }
        , { name = "blowfish", unicode = "🐡", tags = [], x = 552, y = 138 }
        , { name = "dolphin", unicode = "🐬", tags = [], x = 828, y = 874 }
        , { name = "shark", unicode = "🦈", tags = [], x = 1564, y = 506 }
        , { name = "whale", unicode = "🐳", tags = [ "sea" ], x = 1748, y = 92 }
        , { name = "whale2", unicode = "🐋", tags = [], x = 1748, y = 138 }
        , { name = "crocodile", unicode = "🐊", tags = [], x = 138, y = 828 }
        , { name = "leopard", unicode = "🐆", tags = [], x = 1242, y = 460 }
        , { name = "tiger2", unicode = "🐅", tags = [], x = 0, y = 1656 }
        , { name = "water_buffalo", unicode = "🐃", tags = [], x = 1288, y = 1702 }
        , { name = "ox", unicode = "🐂", tags = [], x = 1426, y = 322 }
        , { name = "cow2", unicode = "🐄", tags = [], x = 828, y = 598 }
        , { name = "deer", unicode = "🦌", tags = [], x = 874, y = 782 }
        , { name = "dromedary_camel", unicode = "🐪", tags = [ "desert" ], x = 920, y = 322 }
        , { name = "camel", unicode = "🐫", tags = [], x = 644, y = 322 }
        , { name = "elephant", unicode = "🐘", tags = [], x = 460, y = 920 }
        , { name = "rhinoceros", unicode = "🦏", tags = [], x = 1518, y = 736 }
        , { name = "gorilla", unicode = "🦍", tags = [], x = 1058, y = 1058 }
        , { name = "racehorse", unicode = "🐎", tags = [ "speed" ], x = 460, y = 1472 }
        , { name = "pig2", unicode = "🐖", tags = [], x = 966, y = 1426 }
        , { name = "goat", unicode = "🐐", tags = [], x = 782, y = 1058 }
        , { name = "ram", unicode = "🐏", tags = [], x = 1426, y = 1472 }
        , { name = "sheep", unicode = "🐑", tags = [], x = 1564, y = 598 }
        , { name = "dog2", unicode = "🐕", tags = [], x = 690, y = 874 }
        , { name = "poodle", unicode = "🐩", tags = [ "dog" ], x = 1472, y = 414 }
        , { name = "cat2", unicode = "🐈", tags = [], x = 690, y = 0 }
        , { name = "rooster", unicode = "🐓", tags = [], x = 1518, y = 1380 }
        , { name = "turkey", unicode = "🦃", tags = [ "thanksgiving" ], x = 1702, y = 138 }
        , { name = "dove", unicode = "🕊", tags = [ "peace" ], x = 920, y = 138 }
        , { name = "rabbit2", unicode = "🐇", tags = [], x = 414, y = 1472 }
        , { name = "mouse2", unicode = "🐁", tags = [], x = 46, y = 1334 }
        , { name = "rat", unicode = "🐀", tags = [], x = 1518, y = 0 }
        , { name = "chipmunk", unicode = "🐿", tags = [], x = 138, y = 690 }
        , { name = "feet", unicode = "🐾", tags = [], x = 1012, y = 230 }
        , { name = "dragon", unicode = "🐉", tags = [], x = 920, y = 184 }
        , { name = "dragon_face", unicode = "🐲", tags = [], x = 920, y = 230 }
        , { name = "cactus", unicode = "🌵", tags = [], x = 644, y = 46 }
        , { name = "christmas_tree", unicode = "🎄", tags = [], x = 276, y = 690 }
        , { name = "evergreen_tree", unicode = "🌲", tags = [ "wood" ], x = 966, y = 184 }
        , { name = "deciduous_tree", unicode = "🌳", tags = [ "wood" ], x = 874, y = 736 }
        , { name = "palm_tree", unicode = "🌴", tags = [], x = 1426, y = 736 }
        , { name = "seedling", unicode = "🌱", tags = [ "plant" ], x = 1564, y = 138 }
        , { name = "herb", unicode = "🌿", tags = [], x = 1150, y = 414 }
        , { name = "shamrock", unicode = "☘️", tags = [], x = 1564, y = 460 }
        , { name = "four_leaf_clover", unicode = "🍀", tags = [ "luck" ], x = 1058, y = 138 }
        , { name = "bamboo", unicode = "🎍", tags = [], x = 46, y = 414 }
        , { name = "tanabata_tree", unicode = "🎋", tags = [], x = 1656, y = 690 }
        , { name = "leaves", unicode = "🍃", tags = [ "leaf" ], x = 1242, y = 92 }
        , { name = "fallen_leaf", unicode = "🍂", tags = [ "autumn" ], x = 966, y = 736 }
        , { name = "maple_leaf", unicode = "🍁", tags = [ "canada" ], x = 1288, y = 1242 }
        , { name = "mushroom", unicode = "🍄", tags = [], x = 322, y = 1334 }
        , { name = "ear_of_rice", unicode = "🌾", tags = [], x = 920, y = 736 }
        , { name = "bouquet", unicode = "💐", tags = [ "flowers" ], x = 368, y = 552 }
        , { name = "tulip", unicode = "🌷", tags = [ "flower" ], x = 1702, y = 0 }
        , { name = "rose", unicode = "🌹", tags = [ "flower" ], x = 1518, y = 1426 }
        , { name = "wilted_flower", unicode = "🥀", tags = [], x = 1748, y = 690 }
        , { name = "sunflower", unicode = "🌻", tags = [], x = 966, y = 1610 }
        , { name = "blossom", unicode = "🌼", tags = [], x = 552, y = 92 }
        , { name = "cherry_blossom", unicode = "🌸", tags = [ "flower", "spring" ], x = 690, y = 598 }
        , { name = "hibiscus", unicode = "🌺", tags = [], x = 1150, y = 460 }
        , { name = "earth_americas", unicode = "🌎", tags = [ "globe", "world", "international" ], x = 920, y = 828 }
        , { name = "earth_africa", unicode = "🌍", tags = [ "globe", "world", "international" ], x = 920, y = 782 }
        , { name = "earth_asia", unicode = "🌏", tags = [ "globe", "world", "international" ], x = 920, y = 874 }
        , { name = "full_moon", unicode = "🌕", tags = [], x = 1058, y = 966 }
        , { name = "waning_gibbous_moon", unicode = "🌖", tags = [], x = 1104, y = 1702 }
        , { name = "last_quarter_moon", unicode = "🌗", tags = [], x = 1104, y = 1196 }
        , { name = "waning_crescent_moon", unicode = "🌘", tags = [], x = 1058, y = 1702 }
        , { name = "new_moon", unicode = "🌑", tags = [], x = 1288, y = 1334 }
        , { name = "waxing_crescent_moon", unicode = "🌒", tags = [], x = 1472, y = 1702 }
        , { name = "first_quarter_moon", unicode = "🌓", tags = [], x = 1012, y = 920 }
        , { name = "moon", unicode = "🌔", tags = [], x = 1334, y = 598 }
        , { name = "new_moon_with_face", unicode = "🌚", tags = [], x = 1334, y = 1334 }
        , { name = "full_moon_with_face", unicode = "🌝", tags = [], x = 1058, y = 1012 }
        , { name = "sun_with_face", unicode = "🌞", tags = [ "summer" ], x = 920, y = 1610 }
        , { name = "first_quarter_moon_with_face", unicode = "🌛", tags = [], x = 1012, y = 966 }
        , { name = "last_quarter_moon_with_face", unicode = "🌜", tags = [], x = 1150, y = 1196 }
        , { name = "crescent_moon", unicode = "🌙", tags = [ "night" ], x = 0, y = 828 }
        , { name = "dizzy", unicode = "💫", tags = [ "star" ], x = 460, y = 874 }
        , { name = "star", unicode = "⭐️", tags = [], x = 1610, y = 1472 }
        , { name = "star2", unicode = "🌟", tags = [], x = 1610, y = 1518 }
        , { name = "sparkles", unicode = "✨", tags = [ "shiny" ], x = 1610, y = 460 }
        , { name = "zap", unicode = "⚡️", tags = [ "lightning", "thunder" ], x = 1012, y = 1748 }
        , { name = "fire", unicode = "🔥", tags = [ "burn" ], x = 1012, y = 782 }
        , { name = "boom", unicode = "💥", tags = [ "explode" ], x = 184, y = 552 }
        , { name = "comet", unicode = "☄", tags = [], x = 782, y = 598 }
        , { name = "sunny", unicode = "☀️", tags = [ "weather" ], x = 1058, y = 1610 }
        , { name = "sun_behind_small_cloud", unicode = "🌤", tags = [], x = 874, y = 1610 }
        , { name = "partly_sunny", unicode = "⛅️", tags = [ "weather", "cloud" ], x = 1426, y = 1242 }
        , { name = "sun_behind_large_cloud", unicode = "🌥", tags = [], x = 782, y = 1610 }
        , { name = "sun_behind_rain_cloud", unicode = "🌦", tags = [], x = 828, y = 1610 }
        , { name = "rainbow", unicode = "🌈", tags = [], x = 1012, y = 1472 }
        , { name = "cloud", unicode = "☁️", tags = [], x = 690, y = 736 }
        , { name = "cloud_with_rain", unicode = "🌧", tags = [], x = 782, y = 46 }
        , { name = "cloud_with_lightning_and_rain", unicode = "⛈", tags = [], x = 782, y = 0 }
        , { name = "cloud_with_lightning", unicode = "🌩", tags = [], x = 736, y = 736 }
        , { name = "cloud_with_snow", unicode = "🌨", tags = [], x = 782, y = 92 }
        , { name = "snowman_with_snow", unicode = "☃️", tags = [ "winter", "christmas" ], x = 1334, y = 1564 }
        , { name = "snowman", unicode = "⛄️", tags = [ "winter" ], x = 1288, y = 1564 }
        , { name = "snowflake", unicode = "❄️", tags = [ "winter", "cold", "weather" ], x = 1242, y = 1564 }
        , { name = "wind_face", unicode = "🌬", tags = [], x = 1748, y = 782 }
        , { name = "dash", unicode = "💨", tags = [ "wind", "blow", "fast" ], x = 874, y = 598 }
        , { name = "tornado", unicode = "🌪", tags = [], x = 736, y = 1656 }
        , { name = "fog", unicode = "🌫", tags = [], x = 828, y = 1012 }
        , { name = "ocean", unicode = "🌊", tags = [ "sea" ], x = 276, y = 1380 }
        , { name = "droplet", unicode = "💧", tags = [ "water" ], x = 920, y = 414 }
        , { name = "sweat_drops", unicode = "💦", tags = [ "water", "workout" ], x = 1610, y = 1610 }
        , { name = "umbrella", unicode = "☔️", tags = [ "rain", "weather" ], x = 1702, y = 1288 }
        , { name = "green_apple", unicode = "🍏", tags = [ "fruit" ], x = 1104, y = 92 }
        , { name = "apple", unicode = "🍎", tags = [], x = 276, y = 0 }
        , { name = "pear", unicode = "🍐", tags = [], x = 184, y = 1426 }
        , { name = "tangerine", unicode = "🍊", tags = [], x = 1656, y = 736 }
        , { name = "lemon", unicode = "🍋", tags = [], x = 1242, y = 368 }
        , { name = "banana", unicode = "🍌", tags = [ "fruit" ], x = 92, y = 414 }
        , { name = "watermelon", unicode = "🍉", tags = [], x = 1334, y = 1702 }
        , { name = "grapes", unicode = "🍇", tags = [], x = 1104, y = 0 }
        , { name = "strawberry", unicode = "🍓", tags = [ "fruit" ], x = 460, y = 1610 }
        , { name = "melon", unicode = "🍈", tags = [], x = 644, y = 1288 }
        , { name = "cherries", unicode = "🍒", tags = [ "fruit" ], x = 690, y = 552 }
        , { name = "peach", unicode = "🍑", tags = [], x = 92, y = 1426 }
        , { name = "pineapple", unicode = "🍍", tags = [], x = 1104, y = 1426 }
        , { name = "kiwi_fruit", unicode = "🥝", tags = [], x = 460, y = 1196 }
        , { name = "avocado", unicode = "🥑", tags = [], x = 46, y = 368 }
        , { name = "tomato", unicode = "🍅", tags = [], x = 506, y = 1656 }
        , { name = "eggplant", unicode = "🍆", tags = [ "aubergine" ], x = 92, y = 920 }
        , { name = "cucumber", unicode = "🥒", tags = [], x = 598, y = 828 }
        , { name = "carrot", unicode = "🥕", tags = [], x = 598, y = 644 }
        , { name = "corn", unicode = "🌽", tags = [], x = 782, y = 782 }
        , { name = "hot_pepper", unicode = "🌶", tags = [ "spicy" ], x = 1150, y = 1012 }
        , { name = "potato", unicode = "🥔", tags = [], x = 1472, y = 782 }
        , { name = "sweet_potato", unicode = "🍠", tags = [], x = 1656, y = 92 }
        , { name = "chestnut", unicode = "🌰", tags = [], x = 690, y = 644 }
        , { name = "peanuts", unicode = "🥜", tags = [], x = 138, y = 1426 }
        , { name = "honey_pot", unicode = "🍯", tags = [], x = 1150, y = 736 }
        , { name = "croissant", unicode = "🥐", tags = [], x = 184, y = 828 }
        , { name = "bread", unicode = "🍞", tags = [ "toast" ], x = 598, y = 230 }
        , { name = "baguette_bread", unicode = "🥖", tags = [], x = 414, y = 138 }
        , { name = "cheese", unicode = "🧀", tags = [], x = 690, y = 506 }
        , { name = "egg", unicode = "🥚", tags = [], x = 46, y = 920 }
        , { name = "fried_egg", unicode = "🍳", tags = [ "breakfast" ], x = 1058, y = 506 }
        , { name = "bacon", unicode = "🥓", tags = [], x = 414, y = 0 }
        , { name = "pancakes", unicode = "🥞", tags = [], x = 1426, y = 828 }
        , { name = "fried_shrimp", unicode = "🍤", tags = [ "tempura" ], x = 1058, y = 552 }
        , { name = "poultry_leg", unicode = "🍗", tags = [ "meat", "chicken" ], x = 1472, y = 874 }
        , { name = "meat_on_bone", unicode = "🍖", tags = [], x = 460, y = 1288 }
        , { name = "pizza", unicode = "🍕", tags = [], x = 1288, y = 1426 }
        , { name = "hotdog", unicode = "🌭", tags = [], x = 1150, y = 1058 }
        , { name = "hamburger", unicode = "🍔", tags = [ "burger" ], x = 184, y = 1104 }
        , { name = "fries", unicode = "🍟", tags = [], x = 1058, y = 598 }
        , { name = "stuffed_flatbread", unicode = "🥙", tags = [], x = 690, y = 1610 }
        , { name = "taco", unicode = "🌮", tags = [], x = 1656, y = 506 }
        , { name = "burrito", unicode = "🌯", tags = [], x = 322, y = 598 }
        , { name = "green_salad", unicode = "🥗", tags = [], x = 1104, y = 230 }
        , { name = "shallow_pan_of_food", unicode = "🥘", tags = [ "paella", "curry" ], x = 1564, y = 414 }
        , { name = "spaghetti", unicode = "🍝", tags = [ "pasta" ], x = 1610, y = 322 }
        , { name = "ramen", unicode = "🍜", tags = [ "noodle" ], x = 1472, y = 1472 }
        , { name = "stew", unicode = "🍲", tags = [], x = 230, y = 1610 }
        , { name = "fish_cake", unicode = "🍥", tags = [], x = 46, y = 1012 }
        , { name = "sushi", unicode = "🍣", tags = [], x = 1380, y = 1610 }
        , { name = "bento", unicode = "🍱", tags = [], x = 506, y = 92 }
        , { name = "curry", unicode = "🍛", tags = [], x = 828, y = 828 }
        , { name = "rice", unicode = "🍚", tags = [], x = 1518, y = 828 }
        , { name = "rice_ball", unicode = "🍙", tags = [], x = 1518, y = 874 }
        , { name = "rice_cracker", unicode = "🍘", tags = [], x = 1518, y = 920 }
        , { name = "oden", unicode = "🍢", tags = [], x = 414, y = 1380 }
        , { name = "dango", unicode = "🍡", tags = [], x = 874, y = 460 }
        , { name = "shaved_ice", unicode = "🍧", tags = [], x = 1564, y = 552 }
        , { name = "ice_cream", unicode = "🍨", tags = [], x = 460, y = 1150 }
        , { name = "icecream", unicode = "🍦", tags = [], x = 598, y = 1150 }
        , { name = "cake", unicode = "🍰", tags = [ "dessert" ], x = 644, y = 92 }
        , { name = "birthday", unicode = "🎂", tags = [ "party" ], x = 46, y = 506 }
        , { name = "custard", unicode = "🍮", tags = [], x = 874, y = 0 }
        , { name = "lollipop", unicode = "🍭", tags = [], x = 1242, y = 1196 }
        , { name = "candy", unicode = "🍬", tags = [ "sweet" ], x = 92, y = 644 }
        , { name = "chocolate_bar", unicode = "🍫", tags = [], x = 184, y = 690 }
        , { name = "popcorn", unicode = "🍿", tags = [], x = 1472, y = 506 }
        , { name = "doughnut", unicode = "🍩", tags = [], x = 920, y = 92 }
        , { name = "cookie", unicode = "🍪", tags = [], x = 598, y = 782 }
        , { name = "milk_glass", unicode = "🥛", tags = [], x = 1196, y = 1288 }
        , { name = "baby_bottle", unicode = "🍼", tags = [ "milk" ], x = 230, y = 368 }
        , { name = "coffee", unicode = "☕️", tags = [ "cafe", "espresso" ], x = 782, y = 368 }
        , { name = "tea", unicode = "🍵", tags = [ "green", "breakfast" ], x = 1656, y = 920 }
        , { name = "sake", unicode = "🍶", tags = [], x = 736, y = 1518 }
        , { name = "beer", unicode = "🍺", tags = [ "drink" ], x = 138, y = 460 }
        , { name = "beers", unicode = "🍻", tags = [ "drinks" ], x = 184, y = 460 }
        , { name = "clinking_glasses", unicode = "🥂", tags = [ "cheers", "toast" ], x = 736, y = 92 }
        , { name = "wine_glass", unicode = "🍷", tags = [], x = 1748, y = 828 }
        , { name = "tumbler_glass", unicode = "🥃", tags = [ "whisky" ], x = 1702, y = 46 }
        , { name = "cocktail", unicode = "🍸", tags = [ "drink" ], x = 782, y = 276 }
        , { name = "tropical_drink", unicode = "🍹", tags = [ "summer", "vacation" ], x = 1472, y = 1656 }
        , { name = "champagne", unicode = "🍾", tags = [ "bottle", "bubbly", "celebration" ], x = 690, y = 276 }
        , { name = "spoon", unicode = "🥄", tags = [], x = 1610, y = 966 }
        , { name = "fork_and_knife", unicode = "🍴", tags = [ "cutlery" ], x = 1012, y = 1012 }
        , { name = "plate_with_cutlery", unicode = "🍽", tags = [ "dining", "dinner" ], x = 1380, y = 1426 }
        ]
    , objects =
        [ { name = "soccer", unicode = "⚽️", tags = [ "sports" ], x = 1426, y = 1564 }
        , { name = "basketball", unicode = "🏀", tags = [ "sports" ], x = 460, y = 92 }
        , { name = "football", unicode = "🏈", tags = [ "sports" ], x = 920, y = 1012 }
        , { name = "baseball", unicode = "⚾️", tags = [ "sports" ], x = 414, y = 414 }
        , { name = "tennis", unicode = "🎾", tags = [ "sports" ], x = 1656, y = 1104 }
        , { name = "volleyball", unicode = "🏐", tags = [], x = 736, y = 1702 }
        , { name = "rugby_football", unicode = "🏉", tags = [], x = 276, y = 1518 }
        , { name = "8ball", unicode = "🎱", tags = [ "pool", "billiards" ], x = 46, y = 92 }
        , { name = "ping_pong", unicode = "🏓", tags = [], x = 1150, y = 1426 }
        , { name = "badminton", unicode = "🏸", tags = [], x = 414, y = 46 }
        , { name = "goal_net", unicode = "🥅", tags = [], x = 736, y = 1058 }
        , { name = "ice_hockey", unicode = "🏒", tags = [], x = 506, y = 1150 }
        , { name = "field_hockey", unicode = "🏑", tags = [], x = 1012, y = 414 }
        , { name = "cricket", unicode = "🏏", tags = [], x = 46, y = 828 }
        , { name = "golf", unicode = "⛳️", tags = [], x = 920, y = 1058 }
        , { name = "bow_and_arrow", unicode = "🏹", tags = [ "archery" ], x = 460, y = 552 }
        , { name = "fishing_pole_and_fish", unicode = "🎣", tags = [], x = 92, y = 1012 }
        , { name = "boxing_glove", unicode = "🥊", tags = [], x = 598, y = 92 }
        , { name = "martial_arts_uniform", unicode = "🥋", tags = [], x = 46, y = 1288 }
        , { name = "ice_skate", unicode = "⛸", tags = [ "skating" ], x = 552, y = 1150 }
        , { name = "ski", unicode = "🎿", tags = [], x = 1564, y = 1472 }
        , { name = "skier", unicode = "⛷", tags = [], x = 1564, y = 1518 }
        , { name = "snowboarder", unicode = "🏂", tags = [], x = 1196, y = 1564 }
        , { name = "weight_lifting_woman", unicode = "🏋️\u{200D}♀️️", tags = [ "gym", "workout" ], x = 1748, y = 0 }
        , { name = "weight_lifting_man", unicode = "🏋", tags = [ "gym", "workout" ], x = 1702, y = 1702 }
        , { name = "person_fencing", unicode = "🤺", tags = [], x = 552, y = 1426 }
        , { name = "women_wrestling", unicode = "🤼\u{200D}♀️", tags = [], x = 414, y = 1748 }
        , { name = "men_wrestling", unicode = "🤼\u{200D}♂️", tags = [], x = 736, y = 1288 }
        , { name = "woman_cartwheeling", unicode = "🤸\u{200D}♀️", tags = [], x = 1748, y = 1104 }
        , { name = "man_cartwheeling", unicode = "🤸\u{200D}♂️", tags = [], x = 1288, y = 0 }
        , { name = "basketball_woman", unicode = "⛹️\u{200D}♀️️", tags = [], x = 460, y = 184 }
        , { name = "basketball_man", unicode = "⛹", tags = [], x = 460, y = 138 }
        , { name = "woman_playing_handball", unicode = "🤾\u{200D}♀️", tags = [], x = 1748, y = 1656 }
        , { name = "man_playing_handball", unicode = "🤾\u{200D}♂️", tags = [], x = 1288, y = 644 }
        , { name = "golfing_woman", unicode = "🏌️\u{200D}♀️️", tags = [], x = 1012, y = 1058 }
        , { name = "golfing_man", unicode = "🏌", tags = [], x = 966, y = 1058 }
        , { name = "surfing_woman", unicode = "🏄\u{200D}♀️", tags = [], x = 1288, y = 1610 }
        , { name = "surfing_man", unicode = "🏄", tags = [], x = 1242, y = 1610 }
        , { name = "swimming_woman", unicode = "🏊\u{200D}♀️", tags = [], x = 1656, y = 230 }
        , { name = "swimming_man", unicode = "🏊", tags = [], x = 1656, y = 184 }
        , { name = "woman_playing_water_polo", unicode = "🤽\u{200D}♀️", tags = [], x = 1748, y = 1702 }
        , { name = "man_playing_water_polo", unicode = "🤽\u{200D}♂️", tags = [], x = 1288, y = 690 }
        , { name = "rowing_woman", unicode = "🚣\u{200D}♀️", tags = [], x = 184, y = 1518 }
        , { name = "rowing_man", unicode = "🚣", tags = [], x = 138, y = 1518 }
        , { name = "horse_racing", unicode = "🏇", tags = [], x = 1150, y = 920 }
        , { name = "biking_woman", unicode = "🚴\u{200D}♀️", tags = [], x = 506, y = 368 }
        , { name = "biking_man", unicode = "🚴", tags = [], x = 506, y = 322 }
        , { name = "mountain_biking_woman", unicode = "🚵\u{200D}♀️", tags = [], x = 1334, y = 1150 }
        , { name = "mountain_biking_man", unicode = "🚵", tags = [], x = 1334, y = 1104 }
        , { name = "running_shirt_with_sash", unicode = "🎽", tags = [ "marathon" ], x = 460, y = 1518 }
        , { name = "medal_sports", unicode = "🏅", tags = [ "gold", "winner" ], x = 552, y = 1288 }
        , { name = "medal_military", unicode = "🎖", tags = [], x = 506, y = 1288 }
        , { name = "1st_place_medal", unicode = "🥇", tags = [ "gold" ], x = 92, y = 0 }
        , { name = "2nd_place_medal", unicode = "🥈", tags = [ "silver" ], x = 92, y = 46 }
        , { name = "3rd_place_medal", unicode = "🥉", tags = [ "bronze" ], x = 0, y = 92 }
        , { name = "trophy", unicode = "🏆", tags = [ "award", "contest", "winner" ], x = 1426, y = 1656 }
        , { name = "rosette", unicode = "🏵", tags = [], x = 1518, y = 1472 }
        , { name = "reminder_ribbon", unicode = "🎗", tags = [], x = 1518, y = 368 }
        , { name = "ticket", unicode = "🎫", tags = [], x = 1656, y = 1518 }
        , { name = "tickets", unicode = "🎟", tags = [], x = 1656, y = 1564 }
        , { name = "circus_tent", unicode = "🎪", tags = [], x = 414, y = 690 }
        , { name = "woman_juggling", unicode = "🤹\u{200D}♀️", tags = [], x = 1748, y = 1472 }
        , { name = "man_juggling", unicode = "🤹\u{200D}♂️", tags = [], x = 1288, y = 460 }
        , { name = "performing_arts", unicode = "🎭", tags = [ "theater", "drama" ], x = 460, y = 1426 }
        , { name = "art", unicode = "🎨", tags = [ "design", "paint" ], x = 230, y = 322 }
        , { name = "clapper", unicode = "🎬", tags = [ "film" ], x = 736, y = 0 }
        , { name = "microphone", unicode = "🎤", tags = [ "sing" ], x = 1058, y = 1288 }
        , { name = "headphones", unicode = "🎧", tags = [ "music", "earphones" ], x = 736, y = 1104 }
        , { name = "musical_score", unicode = "🎼", tags = [], x = 460, y = 1334 }
        , { name = "musical_keyboard", unicode = "🎹", tags = [ "piano" ], x = 368, y = 1334 }
        , { name = "drum", unicode = "🥁", tags = [], x = 920, y = 460 }
        , { name = "saxophone", unicode = "🎷", tags = [], x = 1150, y = 1518 }
        , { name = "trumpet", unicode = "🎺", tags = [], x = 1610, y = 1656 }
        , { name = "guitar", unicode = "🎸", tags = [ "rock" ], x = 1104, y = 966 }
        , { name = "violin", unicode = "🎻", tags = [], x = 598, y = 1702 }
        , { name = "game_die", unicode = "🎲", tags = [ "dice", "gambling" ], x = 138, y = 1058 }
        , { name = "dart", unicode = "🎯", tags = [ "target" ], x = 874, y = 552 }
        , { name = "bowling", unicode = "🎳", tags = [], x = 598, y = 0 }
        , { name = "video_game", unicode = "🎮", tags = [ "play", "controller", "console" ], x = 506, y = 1702 }
        , { name = "slot_machine", unicode = "🎰", tags = [], x = 322, y = 1564 }
        , { name = "watch", unicode = "⌚️", tags = [ "time" ], x = 1242, y = 1702 }
        , { name = "iphone", unicode = "📱", tags = [ "smartphone", "mobile" ], x = 1196, y = 0 }
        , { name = "calling", unicode = "📲", tags = [ "call", "incoming" ], x = 644, y = 230 }
        , { name = "computer", unicode = "💻", tags = [ "desktop", "screen" ], x = 782, y = 690 }
        , { name = "keyboard", unicode = "⌨️", tags = [], x = 1196, y = 1150 }
        , { name = "desktop_computer", unicode = "🖥", tags = [], x = 184, y = 874 }
        , { name = "printer", unicode = "🖨", tags = [], x = 1472, y = 1426 }
        , { name = "computer_mouse", unicode = "🖱", tags = [], x = 782, y = 736 }
        , { name = "trackball", unicode = "🖲", tags = [], x = 828, y = 1656 }
        , { name = "joystick", unicode = "🕹", tags = [], x = 1196, y = 874 }
        , { name = "clamp", unicode = "🗜", tags = [], x = 644, y = 690 }
        , { name = "minidisc", unicode = "💽", tags = [], x = 1334, y = 0 }
        , { name = "floppy_disk", unicode = "💾", tags = [ "save" ], x = 690, y = 1012 }
        , { name = "cd", unicode = "💿", tags = [], x = 690, y = 92 }
        , { name = "dvd", unicode = "📀", tags = [], x = 920, y = 552 }
        , { name = "vhs", unicode = "📼", tags = [], x = 368, y = 1702 }
        , { name = "camera", unicode = "📷", tags = [ "photo" ], x = 644, y = 368 }
        , { name = "camera_flash", unicode = "📸", tags = [ "photo" ], x = 644, y = 414 }
        , { name = "video_camera", unicode = "📹", tags = [], x = 460, y = 1702 }
        , { name = "movie_camera", unicode = "🎥", tags = [ "film", "video" ], x = 92, y = 1334 }
        , { name = "film_projector", unicode = "📽", tags = [], x = 1012, y = 598 }
        , { name = "film_strip", unicode = "🎞", tags = [], x = 1012, y = 644 }
        , { name = "telephone_receiver", unicode = "📞", tags = [ "phone", "call" ], x = 1656, y = 1012 }
        , { name = "phone", unicode = "☎️", tags = [], x = 828, y = 1426 }
        , { name = "pager", unicode = "📟", tags = [], x = 1426, y = 506 }
        , { name = "fax", unicode = "📠", tags = [], x = 1012, y = 92 }
        , { name = "tv", unicode = "📺", tags = [], x = 1702, y = 368 }
        , { name = "radio", unicode = "📻", tags = [ "podcast" ], x = 552, y = 1472 }
        , { name = "studio_microphone", unicode = "🎙", tags = [ "podcast" ], x = 644, y = 1610 }
        , { name = "level_slider", unicode = "🎚", tags = [], x = 1242, y = 552 }
        , { name = "control_knobs", unicode = "🎛", tags = [], x = 460, y = 782 }
        , { name = "stopwatch", unicode = "⏱", tags = [], x = 368, y = 1610 }
        , { name = "timer_clock", unicode = "⏲", tags = [], x = 46, y = 1656 }
        , { name = "alarm_clock", unicode = "⏰", tags = [ "morning" ], x = 184, y = 46 }
        , { name = "mantelpiece_clock", unicode = "🕰", tags = [], x = 1288, y = 1196 }
        , { name = "hourglass", unicode = "⌛️", tags = [ "time" ], x = 46, y = 1150 }
        , { name = "hourglass_flowing_sand", unicode = "⏳", tags = [ "time" ], x = 92, y = 1150 }
        , { name = "satellite", unicode = "📡", tags = [ "signal" ], x = 1012, y = 1518 }
        , { name = "battery", unicode = "🔋", tags = [ "power" ], x = 460, y = 368 }
        , { name = "electric_plug", unicode = "🔌", tags = [], x = 368, y = 920 }
        , { name = "bulb", unicode = "💡", tags = [ "idea", "light" ], x = 92, y = 598 }
        , { name = "flashlight", unicode = "🔦", tags = [], x = 460, y = 1012 }
        , { name = "candle", unicode = "🕯", tags = [], x = 46, y = 644 }
        , { name = "wastebasket", unicode = "🗑", tags = [ "trash" ], x = 1196, y = 1702 }
        , { name = "oil_drum", unicode = "🛢", tags = [], x = 506, y = 1380 }
        , { name = "money_with_wings", unicode = "💸", tags = [ "dollar" ], x = 1334, y = 230 }
        , { name = "dollar", unicode = "💵", tags = [ "money" ], x = 736, y = 874 }
        , { name = "yen", unicode = "💴", tags = [], x = 828, y = 1748 }
        , { name = "euro", unicode = "💶", tags = [], x = 966, y = 0 }
        , { name = "pound", unicode = "💷", tags = [], x = 1472, y = 920 }
        , { name = "moneybag", unicode = "💰", tags = [ "dollar", "cream" ], x = 1334, y = 276 }
        , { name = "credit_card", unicode = "💳", tags = [ "subscription" ], x = 828, y = 782 }
        , { name = "gem", unicode = "💎", tags = [ "diamond" ], x = 276, y = 1058 }
        , { name = "balance_scale", unicode = "⚖️", tags = [], x = 414, y = 276 }
        , { name = "wrench", unicode = "🔧", tags = [ "tool" ], x = 598, y = 1748 }
        , { name = "hammer", unicode = "🔨", tags = [ "tool" ], x = 230, y = 1104 }
        , { name = "hammer_and_pick", unicode = "⚒", tags = [], x = 276, y = 1104 }
        , { name = "hammer_and_wrench", unicode = "🛠", tags = [], x = 322, y = 1104 }
        , { name = "pick", unicode = "⛏", tags = [], x = 874, y = 1426 }
        , { name = "nut_and_bolt", unicode = "🔩", tags = [], x = 138, y = 1380 }
        , { name = "gear", unicode = "⚙️", tags = [], x = 230, y = 1058 }
        , { name = "chains", unicode = "⛓", tags = [], x = 690, y = 230 }
        , { name = "gun", unicode = "🔫", tags = [ "shoot", "weapon" ], x = 1104, y = 1012 }
        , { name = "bomb", unicode = "💣", tags = [ "boom" ], x = 552, y = 506 }
        , { name = "hocho", unicode = "🔪", tags = [ "cut", "chop" ], x = 1150, y = 598 }
        , { name = "dagger", unicode = "🗡", tags = [], x = 874, y = 230 }
        , { name = "crossed_swords", unicode = "⚔️", tags = [], x = 322, y = 828 }
        , { name = "shield", unicode = "🛡", tags = [], x = 1564, y = 690 }
        , { name = "smoking", unicode = "🚬", tags = [ "cigarette" ], x = 1012, y = 1564 }
        , { name = "coffin", unicode = "⚰️", tags = [ "funeral" ], x = 782, y = 414 }
        , { name = "funeral_urn", unicode = "⚱️", tags = [], x = 0, y = 1058 }
        , { name = "amphora", unicode = "🏺", tags = [], x = 184, y = 184 }
        , { name = "crystal_ball", unicode = "🔮", tags = [ "fortune" ], x = 506, y = 828 }
        , { name = "prayer_beads", unicode = "📿", tags = [], x = 1472, y = 1196 }
        , { name = "barber", unicode = "💈", tags = [], x = 368, y = 414 }
        , { name = "alembic", unicode = "⚗️", tags = [], x = 184, y = 138 }
        , { name = "telescope", unicode = "🔭", tags = [], x = 1656, y = 1058 }
        , { name = "microscope", unicode = "🔬", tags = [ "science", "laboratory", "investigate" ], x = 1104, y = 1288 }
        , { name = "hole", unicode = "🕳", tags = [], x = 1150, y = 644 }
        , { name = "pill", unicode = "💊", tags = [ "health", "medicine" ], x = 1058, y = 1426 }
        , { name = "syringe", unicode = "💉", tags = [ "health", "hospital", "needle" ], x = 1656, y = 460 }
        , { name = "thermometer", unicode = "🌡", tags = [], x = 1656, y = 1242 }
        , { name = "toilet", unicode = "🚽", tags = [ "wc" ], x = 368, y = 1656 }
        , { name = "potable_water", unicode = "🚰", tags = [], x = 1472, y = 736 }
        , { name = "shower", unicode = "🚿", tags = [ "bath" ], x = 1564, y = 1104 }
        , { name = "bathtub", unicode = "🛁", tags = [], x = 460, y = 322 }
        , { name = "bath", unicode = "🛀", tags = [ "shower" ], x = 460, y = 276 }
        , { name = "bellhop_bell", unicode = "🛎", tags = [], x = 506, y = 0 }
        , { name = "key", unicode = "🔑", tags = [ "lock", "password" ], x = 1196, y = 1104 }
        , { name = "old_key", unicode = "🗝", tags = [], x = 736, y = 1380 }
        , { name = "door", unicode = "🚪", tags = [], x = 920, y = 46 }
        , { name = "couch_and_lamp", unicode = "🛋", tags = [], x = 828, y = 92 }
        , { name = "bed", unicode = "🛏", tags = [], x = 46, y = 460 }
        , { name = "sleeping_bed", unicode = "🛌", tags = [], x = 138, y = 1564 }
        , { name = "framed_picture", unicode = "🖼", tags = [], x = 1058, y = 276 }
        , { name = "shopping", unicode = "🛍", tags = [ "bags" ], x = 1564, y = 1012 }
        , { name = "shopping_cart", unicode = "🛒", tags = [], x = 1564, y = 1058 }
        , { name = "gift", unicode = "🎁", tags = [ "present", "birthday", "christmas" ], x = 552, y = 1058 }
        , { name = "balloon", unicode = "🎈", tags = [ "party", "birthday" ], x = 414, y = 322 }
        , { name = "flags", unicode = "🎏", tags = [], x = 414, y = 1012 }
        , { name = "ribbon", unicode = "🎀", tags = [], x = 1518, y = 782 }
        , { name = "confetti_ball", unicode = "🎊", tags = [], x = 0, y = 782 }
        , { name = "tada", unicode = "🎉", tags = [ "hooray", "party" ], x = 1656, y = 552 }
        , { name = "dolls", unicode = "🎎", tags = [], x = 782, y = 874 }
        , { name = "izakaya_lantern", unicode = "🏮", tags = [], x = 1196, y = 322 }
        , { name = "wind_chime", unicode = "🎐", tags = [], x = 1748, y = 736 }
        , { name = "email", unicode = "✉️", tags = [ "letter" ], x = 506, y = 920 }
        , { name = "envelope_with_arrow", unicode = "📩", tags = [], x = 644, y = 920 }
        , { name = "incoming_envelope", unicode = "📨", tags = [], x = 874, y = 1150 }
        , { name = "e-mail", unicode = "📧", tags = [], x = 920, y = 598 }
        , { name = "love_letter", unicode = "💌", tags = [ "email", "envelope" ], x = 184, y = 1242 }
        , { name = "inbox_tray", unicode = "📥", tags = [], x = 828, y = 1150 }
        , { name = "outbox_tray", unicode = "📤", tags = [], x = 1426, y = 230 }
        , { name = "package", unicode = "📦", tags = [ "shipping" ], x = 1426, y = 368 }
        , { name = "label", unicode = "🏷", tags = [ "tag" ], x = 828, y = 1196 }
        , { name = "mailbox_closed", unicode = "📪", tags = [], x = 736, y = 1242 }
        , { name = "mailbox", unicode = "📫", tags = [], x = 690, y = 1242 }
        , { name = "mailbox_with_mail", unicode = "📬", tags = [], x = 782, y = 1242 }
        , { name = "mailbox_with_no_mail", unicode = "📭", tags = [], x = 828, y = 1242 }
        , { name = "postbox", unicode = "📮", tags = [], x = 1472, y = 690 }
        , { name = "postal_horn", unicode = "📯", tags = [], x = 1472, y = 644 }
        , { name = "scroll", unicode = "📜", tags = [ "document" ], x = 1518, y = 1518 }
        , { name = "page_with_curl", unicode = "📃", tags = [], x = 1426, y = 460 }
        , { name = "page_facing_up", unicode = "📄", tags = [ "document" ], x = 1426, y = 414 }
        , { name = "bookmark_tabs", unicode = "📑", tags = [], x = 92, y = 552 }
        , { name = "bar_chart", unicode = "📊", tags = [ "stats", "metrics" ], x = 276, y = 414 }
        , { name = "chart_with_upwards_trend", unicode = "📈", tags = [ "graph", "metrics" ], x = 690, y = 414 }
        , { name = "chart_with_downwards_trend", unicode = "📉", tags = [ "graph", "metrics" ], x = 690, y = 368 }
        , { name = "spiral_notepad", unicode = "🗒", tags = [], x = 1610, y = 920 }
        , { name = "spiral_calendar", unicode = "🗓", tags = [], x = 1610, y = 874 }
        , { name = "calendar", unicode = "📆", tags = [ "schedule" ], x = 644, y = 138 }
        , { name = "date", unicode = "📅", tags = [ "calendar", "schedule" ], x = 874, y = 644 }
        , { name = "card_index", unicode = "📇", tags = [], x = 414, y = 644 }
        , { name = "card_file_box", unicode = "🗃", tags = [], x = 368, y = 644 }
        , { name = "ballot_box", unicode = "🗳", tags = [], x = 414, y = 368 }
        , { name = "file_cabinet", unicode = "🗄", tags = [], x = 1012, y = 506 }
        , { name = "clipboard", unicode = "📋", tags = [], x = 736, y = 138 }
        , { name = "file_folder", unicode = "📁", tags = [ "directory" ], x = 1012, y = 552 }
        , { name = "open_file_folder", unicode = "📂", tags = [], x = 1288, y = 1380 }
        , { name = "card_index_dividers", unicode = "🗂", tags = [], x = 460, y = 644 }
        , { name = "newspaper_roll", unicode = "🗞", tags = [ "press" ], x = 1380, y = 92 }
        , { name = "newspaper", unicode = "📰", tags = [ "press" ], x = 1380, y = 46 }
        , { name = "notebook", unicode = "📓", tags = [], x = 0, y = 1380 }
        , { name = "notebook_with_decorative_cover", unicode = "📔", tags = [], x = 46, y = 1380 }
        , { name = "ledger", unicode = "📒", tags = [], x = 1242, y = 184 }
        , { name = "closed_book", unicode = "📕", tags = [], x = 552, y = 736 }
        , { name = "green_book", unicode = "📗", tags = [], x = 1104, y = 138 }
        , { name = "blue_book", unicode = "📘", tags = [], x = 552, y = 184 }
        , { name = "orange_book", unicode = "📙", tags = [], x = 1426, y = 138 }
        , { name = "books", unicode = "📚", tags = [ "library" ], x = 138, y = 552 }
        , { name = "book", unicode = "📖", tags = [], x = 0, y = 552 }
        , { name = "bookmark", unicode = "🔖", tags = [], x = 46, y = 552 }
        , { name = "link", unicode = "🔗", tags = [], x = 1242, y = 828 }
        , { name = "paperclip", unicode = "📎", tags = [], x = 1426, y = 920 }
        , { name = "paperclips", unicode = "🖇", tags = [], x = 1426, y = 966 }
        , { name = "triangular_ruler", unicode = "📐", tags = [], x = 1150, y = 1656 }
        , { name = "straight_ruler", unicode = "📏", tags = [], x = 414, y = 1610 }
        , { name = "pushpin", unicode = "📌", tags = [ "location" ], x = 184, y = 1472 }
        , { name = "round_pushpin", unicode = "📍", tags = [ "location" ], x = 46, y = 1518 }
        , { name = "scissors", unicode = "✂️", tags = [ "cut" ], x = 1288, y = 1518 }
        , { name = "pen", unicode = "🖊", tags = [], x = 230, y = 1426 }
        , { name = "fountain_pen", unicode = "🖋", tags = [], x = 1058, y = 46 }
        , { name = "black_nib", unicode = "✒️", tags = [], x = 414, y = 506 }
        , { name = "paintbrush", unicode = "🖌", tags = [], x = 1426, y = 552 }
        , { name = "crayon", unicode = "🖍", tags = [], x = 828, y = 736 }
        , { name = "memo", unicode = "📝", tags = [ "document", "note" ], x = 690, y = 1288 }
        , { name = "pencil2", unicode = "✏️", tags = [], x = 322, y = 1426 }
        , { name = "mag", unicode = "🔍", tags = [ "search", "zoom" ], x = 552, y = 1242 }
        , { name = "mag_right", unicode = "🔎", tags = [], x = 598, y = 1242 }
        , { name = "lock_with_ink_pen", unicode = "🔏", tags = [], x = 1242, y = 1150 }
        , { name = "closed_lock_with_key", unicode = "🔐", tags = [ "security" ], x = 598, y = 736 }
        , { name = "lock", unicode = "🔒", tags = [ "security", "private" ], x = 1242, y = 1104 }
        , { name = "unlock", unicode = "🔓", tags = [ "security" ], x = 1702, y = 1518 }
        ]
    , places =
        [ { name = "car", unicode = "🚗", tags = [], x = 322, y = 644 }
        , { name = "taxi", unicode = "🚕", tags = [], x = 1656, y = 874 }
        , { name = "blue_car", unicode = "🚙", tags = [], x = 552, y = 230 }
        , { name = "bus", unicode = "🚌", tags = [], x = 414, y = 598 }
        , { name = "trolleybus", unicode = "🚎", tags = [], x = 1334, y = 1656 }
        , { name = "racing_car", unicode = "🏎", tags = [], x = 506, y = 1472 }
        , { name = "police_car", unicode = "🚓", tags = [], x = 1472, y = 276 }
        , { name = "ambulance", unicode = "🚑", tags = [], x = 92, y = 184 }
        , { name = "fire_engine", unicode = "🚒", tags = [], x = 1012, y = 828 }
        , { name = "minibus", unicode = "🚐", tags = [], x = 1288, y = 1288 }
        , { name = "truck", unicode = "🚚", tags = [], x = 1564, y = 1656 }
        , { name = "articulated_lorry", unicode = "🚛", tags = [], x = 276, y = 322 }
        , { name = "tractor", unicode = "🚜", tags = [], x = 874, y = 1656 }
        , { name = "kick_scooter", unicode = "🛴", tags = [], x = 46, y = 1196 }
        , { name = "bike", unicode = "🚲", tags = [ "bicycle" ], x = 506, y = 276 }
        , { name = "motor_scooter", unicode = "🛵", tags = [], x = 1334, y = 828 }
        , { name = "motorcycle", unicode = "🏍", tags = [], x = 1334, y = 874 }
        , { name = "rotating_light", unicode = "🚨", tags = [ "911", "emergency" ], x = 0, y = 1518 }
        , { name = "oncoming_police_car", unicode = "🚔", tags = [], x = 1104, y = 1380 }
        , { name = "oncoming_bus", unicode = "🚍", tags = [], x = 1058, y = 1380 }
        , { name = "oncoming_automobile", unicode = "🚘", tags = [], x = 1012, y = 1380 }
        , { name = "oncoming_taxi", unicode = "🚖", tags = [], x = 1150, y = 1380 }
        , { name = "aerial_tramway", unicode = "🚡", tags = [], x = 46, y = 138 }
        , { name = "mountain_cableway", unicode = "🚠", tags = [], x = 1334, y = 1196 }
        , { name = "suspension_railway", unicode = "🚟", tags = [], x = 1472, y = 1610 }
        , { name = "railway_car", unicode = "🚃", tags = [], x = 920, y = 1472 }
        , { name = "train", unicode = "🚋", tags = [], x = 966, y = 1656 }
        , { name = "mountain_railway", unicode = "🚞", tags = [], x = 1334, y = 1242 }
        , { name = "monorail", unicode = "🚝", tags = [], x = 1334, y = 460 }
        , { name = "bullettrain_side", unicode = "🚄", tags = [ "train" ], x = 230, y = 598 }
        , { name = "bullettrain_front", unicode = "🚅", tags = [ "train" ], x = 184, y = 598 }
        , { name = "light_rail", unicode = "🚈", tags = [], x = 1242, y = 782 }
        , { name = "steam_locomotive", unicode = "🚂", tags = [ "train" ], x = 184, y = 1610 }
        , { name = "train2", unicode = "🚆", tags = [], x = 1012, y = 1656 }
        , { name = "metro", unicode = "🚇", tags = [], x = 920, y = 1288 }
        , { name = "tram", unicode = "🚊", tags = [], x = 1058, y = 1656 }
        , { name = "station", unicode = "🚉", tags = [], x = 92, y = 1610 }
        , { name = "helicopter", unicode = "🚁", tags = [], x = 1150, y = 368 }
        , { name = "small_airplane", unicode = "🛩", tags = [ "flight" ], x = 460, y = 1564 }
        , { name = "airplane", unicode = "✈️", tags = [ "flight" ], x = 138, y = 138 }
        , { name = "flight_departure", unicode = "🛫", tags = [], x = 598, y = 1012 }
        , { name = "flight_arrival", unicode = "🛬", tags = [], x = 552, y = 1012 }
        , { name = "rocket", unicode = "🚀", tags = [ "ship", "launch" ], x = 1518, y = 1150 }
        , { name = "artificial_satellite", unicode = "🛰", tags = [ "orbit", "space" ], x = 322, y = 322 }
        , { name = "seat", unicode = "💺", tags = [], x = 1564, y = 0 }
        , { name = "canoe", unicode = "🛶", tags = [], x = 138, y = 644 }
        , { name = "boat", unicode = "⛵️", tags = [], x = 552, y = 414 }
        , { name = "motor_boat", unicode = "🛥", tags = [], x = 1334, y = 782 }
        , { name = "speedboat", unicode = "🚤", tags = [ "ship" ], x = 1610, y = 736 }
        , { name = "passenger_ship", unicode = "🛳", tags = [ "cruise" ], x = 1426, y = 1288 }
        , { name = "ferry", unicode = "⛴", tags = [], x = 1012, y = 368 }
        , { name = "ship", unicode = "🚢", tags = [], x = 1564, y = 782 }
        , { name = "anchor", unicode = "⚓️", tags = [ "ship" ], x = 230, y = 0 }
        , { name = "construction", unicode = "🚧", tags = [ "wip" ], x = 276, y = 782 }
        , { name = "fuelpump", unicode = "⛽️", tags = [], x = 1058, y = 920 }
        , { name = "busstop", unicode = "🚏", tags = [], x = 506, y = 598 }
        , { name = "vertical_traffic_light", unicode = "🚦", tags = [ "semaphore" ], x = 322, y = 1702 }
        , { name = "traffic_light", unicode = "🚥", tags = [], x = 920, y = 1656 }
        , { name = "world_map", unicode = "🗺", tags = [ "travel" ], x = 506, y = 1748 }
        , { name = "moyai", unicode = "🗿", tags = [ "stone" ], x = 138, y = 1334 }
        , { name = "statue_of_liberty", unicode = "🗽", tags = [], x = 138, y = 1610 }
        , { name = "fountain", unicode = "⛲️", tags = [], x = 1058, y = 0 }
        , { name = "tokyo_tower", unicode = "🗼", tags = [], x = 460, y = 1656 }
        , { name = "european_castle", unicode = "🏰", tags = [], x = 966, y = 46 }
        , { name = "japanese_castle", unicode = "🏯", tags = [], x = 1196, y = 506 }
        , { name = "stadium", unicode = "🏟", tags = [], x = 1610, y = 1426 }
        , { name = "ferris_wheel", unicode = "🎡", tags = [], x = 1012, y = 322 }
        , { name = "roller_coaster", unicode = "🎢", tags = [], x = 1518, y = 1288 }
        , { name = "carousel_horse", unicode = "🎠", tags = [], x = 552, y = 644 }
        , { name = "parasol_on_ground", unicode = "⛱", tags = [ "beach_umbrella" ], x = 1426, y = 1104 }
        , { name = "beach_umbrella", unicode = "🏖", tags = [], x = 460, y = 414 }
        , { name = "desert_island", unicode = "🏝", tags = [], x = 138, y = 874 }
        , { name = "mountain", unicode = "⛰", tags = [], x = 1334, y = 1012 }
        , { name = "mountain_snow", unicode = "🏔", tags = [], x = 1334, y = 1288 }
        , { name = "mount_fuji", unicode = "🗻", tags = [], x = 1334, y = 966 }
        , { name = "volcano", unicode = "🌋", tags = [], x = 690, y = 1702 }
        , { name = "desert", unicode = "🏜", tags = [], x = 92, y = 874 }
        , { name = "camping", unicode = "🏕", tags = [], x = 644, y = 506 }
        , { name = "tent", unicode = "⛺️", tags = [ "camping" ], x = 1656, y = 1150 }
        , { name = "railway_track", unicode = "🛤", tags = [], x = 966, y = 1472 }
        , { name = "motorway", unicode = "🛣", tags = [], x = 1334, y = 920 }
        , { name = "building_construction", unicode = "🏗", tags = [], x = 46, y = 598 }
        , { name = "factory", unicode = "🏭", tags = [], x = 966, y = 644 }
        , { name = "house", unicode = "🏠", tags = [], x = 138, y = 1150 }
        , { name = "house_with_garden", unicode = "🏡", tags = [], x = 184, y = 1150 }
        , { name = "houses", unicode = "🏘", tags = [], x = 230, y = 1150 }
        , { name = "derelict_house", unicode = "🏚", tags = [], x = 46, y = 874 }
        , { name = "office", unicode = "🏢", tags = [], x = 460, y = 1380 }
        , { name = "department_store", unicode = "🏬", tags = [], x = 0, y = 874 }
        , { name = "post_office", unicode = "🏣", tags = [], x = 1472, y = 598 }
        , { name = "european_post_office", unicode = "🏤", tags = [], x = 966, y = 92 }
        , { name = "hospital", unicode = "🏥", tags = [], x = 1150, y = 966 }
        , { name = "bank", unicode = "🏦", tags = [], x = 230, y = 414 }
        , { name = "hotel", unicode = "🏨", tags = [], x = 1150, y = 1104 }
        , { name = "convenience_store", unicode = "🏪", tags = [], x = 506, y = 782 }
        , { name = "school", unicode = "🏫", tags = [], x = 1196, y = 1518 }
        , { name = "love_hotel", unicode = "🏩", tags = [], x = 138, y = 1242 }
        , { name = "wedding", unicode = "💒", tags = [ "marriage" ], x = 1656, y = 1702 }
        , { name = "classical_building", unicode = "🏛", tags = [], x = 736, y = 46 }
        , { name = "church", unicode = "⛪️", tags = [], x = 322, y = 690 }
        , { name = "mosque", unicode = "🕌", tags = [], x = 1334, y = 736 }
        , { name = "synagogue", unicode = "🕍", tags = [], x = 1656, y = 368 }
        , { name = "kaaba", unicode = "🕋", tags = [], x = 1196, y = 966 }
        , { name = "shinto_shrine", unicode = "⛩", tags = [], x = 1564, y = 736 }
        , { name = "japan", unicode = "🗾", tags = [], x = 1196, y = 460 }
        , { name = "rice_scene", unicode = "🎑", tags = [], x = 1518, y = 966 }
        , { name = "national_park", unicode = "🏞", tags = [], x = 736, y = 1334 }
        , { name = "sunrise", unicode = "🌅", tags = [], x = 1104, y = 1610 }
        , { name = "sunrise_over_mountains", unicode = "🌄", tags = [], x = 1150, y = 1610 }
        , { name = "stars", unicode = "🌠", tags = [], x = 46, y = 1610 }
        , { name = "sparkler", unicode = "🎇", tags = [], x = 1610, y = 414 }
        , { name = "fireworks", unicode = "🎆", tags = [ "festival", "celebration" ], x = 1012, y = 874 }
        , { name = "city_sunrise", unicode = "🌇", tags = [], x = 460, y = 690 }
        , { name = "city_sunset", unicode = "🌆", tags = [], x = 506, y = 690 }
        , { name = "cityscape", unicode = "🏙", tags = [ "skyline" ], x = 552, y = 690 }
        , { name = "night_with_stars", unicode = "🌃", tags = [], x = 1380, y = 460 }
        , { name = "milky_way", unicode = "🌌", tags = [], x = 1242, y = 1288 }
        , { name = "bridge_at_night", unicode = "🌉", tags = [], x = 598, y = 322 }
        , { name = "foggy", unicode = "🌁", tags = [ "karl" ], x = 874, y = 1012 }
        , { name = "white_flag", unicode = "🏳️", tags = [], x = 1748, y = 368 }
        , { name = "black_flag", unicode = "🏴", tags = [], x = 138, y = 506 }
        , { name = "checkered_flag", unicode = "🏁", tags = [ "milestone", "finish" ], x = 690, y = 460 }
        , { name = "triangular_flag_on_post", unicode = "🚩", tags = [], x = 1104, y = 1656 }
        , { name = "rainbow_flag", unicode = "🏳️\u{200D}🌈️", tags = [ "pride" ], x = 1058, y = 1472 }
        , { name = "afghanistan", unicode = "🇦🇫", tags = [], x = 92, y = 138 }
        , { name = "aland_islands", unicode = "🇦🇽", tags = [], x = 184, y = 0 }
        , { name = "albania", unicode = "🇦🇱", tags = [], x = 184, y = 92 }
        , { name = "algeria", unicode = "🇩🇿", tags = [], x = 0, y = 184 }
        , { name = "american_samoa", unicode = "🇦🇸", tags = [], x = 138, y = 184 }
        , { name = "andorra", unicode = "🇦🇩", tags = [], x = 230, y = 46 }
        , { name = "angola", unicode = "🇦🇴", tags = [], x = 230, y = 184 }
        , { name = "anguilla", unicode = "🇦🇮", tags = [], x = 46, y = 230 }
        , { name = "antarctica", unicode = "🇦🇶", tags = [], x = 184, y = 230 }
        , { name = "antigua_barbuda", unicode = "🇦🇬", tags = [], x = 230, y = 230 }
        , { name = "argentina", unicode = "🇦🇷", tags = [], x = 276, y = 92 }
        , { name = "armenia", unicode = "🇦🇲", tags = [], x = 276, y = 184 }
        , { name = "aruba", unicode = "🇦🇼", tags = [], x = 368, y = 0 }
        , { name = "australia", unicode = "🇦🇺", tags = [], x = 368, y = 322 }
        , { name = "austria", unicode = "🇦🇹", tags = [], x = 0, y = 368 }
        , { name = "azerbaijan", unicode = "🇦🇿", tags = [], x = 92, y = 368 }
        , { name = "bahamas", unicode = "🇧🇸", tags = [], x = 414, y = 184 }
        , { name = "bahrain", unicode = "🇧🇭", tags = [], x = 414, y = 230 }
        , { name = "bangladesh", unicode = "🇧🇩", tags = [], x = 184, y = 414 }
        , { name = "barbados", unicode = "🇧🇧", tags = [], x = 322, y = 414 }
        , { name = "belarus", unicode = "🇧🇾", tags = [], x = 322, y = 460 }
        , { name = "belgium", unicode = "🇧🇪", tags = [], x = 368, y = 460 }
        , { name = "belize", unicode = "🇧🇿", tags = [], x = 414, y = 460 }
        , { name = "benin", unicode = "🇧🇯", tags = [], x = 506, y = 46 }
        , { name = "bermuda", unicode = "🇧🇲", tags = [], x = 506, y = 138 }
        , { name = "bhutan", unicode = "🇧🇹", tags = [], x = 506, y = 184 }
        , { name = "bolivia", unicode = "🇧🇴", tags = [], x = 552, y = 460 }
        , { name = "caribbean_netherlands", unicode = "🇧🇶", tags = [], x = 506, y = 644 }
        , { name = "bosnia_herzegovina", unicode = "🇧🇦", tags = [], x = 276, y = 552 }
        , { name = "botswana", unicode = "🇧🇼", tags = [], x = 322, y = 552 }
        , { name = "brazil", unicode = "🇧🇷", tags = [], x = 598, y = 184 }
        , { name = "british_indian_ocean_territory", unicode = "🇮🇴", tags = [], x = 598, y = 414 }
        , { name = "british_virgin_islands", unicode = "🇻🇬", tags = [], x = 598, y = 460 }
        , { name = "brunei", unicode = "🇧🇳", tags = [], x = 598, y = 552 }
        , { name = "bulgaria", unicode = "🇧🇬", tags = [], x = 138, y = 598 }
        , { name = "burkina_faso", unicode = "🇧🇫", tags = [], x = 276, y = 598 }
        , { name = "burundi", unicode = "🇧🇮", tags = [], x = 368, y = 598 }
        , { name = "cape_verde", unicode = "🇨🇻", tags = [], x = 184, y = 644 }
        , { name = "cambodia", unicode = "🇰🇭", tags = [], x = 644, y = 276 }
        , { name = "cameroon", unicode = "🇨🇲", tags = [], x = 644, y = 460 }
        , { name = "canada", unicode = "🇨🇦", tags = [], x = 644, y = 552 }
        , { name = "canary_islands", unicode = "🇮🇨", tags = [], x = 644, y = 598 }
        , { name = "cayman_islands", unicode = "🇰🇾", tags = [], x = 690, y = 46 }
        , { name = "central_african_republic", unicode = "🇨🇫", tags = [], x = 690, y = 138 }
        , { name = "chad", unicode = "🇹🇩", tags = [], x = 690, y = 184 }
        , { name = "chile", unicode = "🇨🇱", tags = [], x = 92, y = 690 }
        , { name = "cn", unicode = "🇨🇳", tags = [ "china" ], x = 782, y = 230 }
        , { name = "christmas_island", unicode = "🇨🇽", tags = [], x = 230, y = 690 }
        , { name = "cocos_islands", unicode = "🇨🇨", tags = [ "keeling" ], x = 782, y = 322 }
        , { name = "colombia", unicode = "🇨🇴", tags = [], x = 782, y = 552 }
        , { name = "comoros", unicode = "🇰🇲", tags = [], x = 782, y = 644 }
        , { name = "congo_brazzaville", unicode = "🇨🇬", tags = [], x = 138, y = 782 }
        , { name = "congo_kinshasa", unicode = "🇨🇩", tags = [], x = 184, y = 782 }
        , { name = "cook_islands", unicode = "🇨🇰", tags = [], x = 552, y = 782 }
        , { name = "costa_rica", unicode = "🇨🇷", tags = [], x = 828, y = 0 }
        , { name = "cote_divoire", unicode = "🇨🇮", tags = [ "ivory" ], x = 828, y = 46 }
        , { name = "croatia", unicode = "🇭🇷", tags = [], x = 92, y = 828 }
        , { name = "cuba", unicode = "🇨🇺", tags = [], x = 552, y = 828 }
        , { name = "curacao", unicode = "🇨🇼", tags = [], x = 690, y = 828 }
        , { name = "cyprus", unicode = "🇨🇾", tags = [], x = 874, y = 138 }
        , { name = "czech_republic", unicode = "🇨🇿", tags = [], x = 874, y = 184 }
        , { name = "denmark", unicode = "🇩🇰", tags = [], x = 874, y = 828 }
        , { name = "djibouti", unicode = "🇩🇯", tags = [], x = 552, y = 874 }
        , { name = "dominica", unicode = "🇩🇲", tags = [], x = 874, y = 874 }
        , { name = "dominican_republic", unicode = "🇩🇴", tags = [], x = 920, y = 0 }
        , { name = "ecuador", unicode = "🇪🇨", tags = [], x = 0, y = 920 }
        , { name = "egypt", unicode = "🇪🇬", tags = [], x = 138, y = 920 }
        , { name = "el_salvador", unicode = "🇸🇻", tags = [], x = 322, y = 920 }
        , { name = "equatorial_guinea", unicode = "🇬🇶", tags = [], x = 690, y = 920 }
        , { name = "eritrea", unicode = "🇪🇷", tags = [], x = 736, y = 920 }
        , { name = "estonia", unicode = "🇪🇪", tags = [], x = 828, y = 920 }
        , { name = "ethiopia", unicode = "🇪🇹", tags = [], x = 874, y = 920 }
        , { name = "eu", unicode = "🇪🇺", tags = [], x = 920, y = 920 }
        , { name = "falkland_islands", unicode = "🇫🇰", tags = [], x = 966, y = 690 }
        , { name = "faroe_islands", unicode = "🇫🇴", tags = [], x = 1012, y = 0 }
        , { name = "fiji", unicode = "🇫🇯", tags = [], x = 1012, y = 460 }
        , { name = "finland", unicode = "🇫🇮", tags = [], x = 1012, y = 690 }
        , { name = "fr", unicode = "🇫🇷", tags = [ "france", "french" ], x = 1058, y = 230 }
        , { name = "french_guiana", unicode = "🇬🇫", tags = [], x = 1058, y = 368 }
        , { name = "french_polynesia", unicode = "🇵🇫", tags = [], x = 1058, y = 414 }
        , { name = "french_southern_territories", unicode = "🇹🇫", tags = [], x = 1058, y = 460 }
        , { name = "gabon", unicode = "🇬🇦", tags = [], x = 46, y = 1058 }
        , { name = "gambia", unicode = "🇬🇲", tags = [], x = 92, y = 1058 }
        , { name = "georgia", unicode = "🇬🇪", tags = [], x = 368, y = 1058 }
        , { name = "de", unicode = "🇩🇪", tags = [ "flag", "germany" ], x = 874, y = 690 }
        , { name = "ghana", unicode = "🇬🇭", tags = [], x = 414, y = 1058 }
        , { name = "gibraltar", unicode = "🇬🇮", tags = [], x = 506, y = 1058 }
        , { name = "greece", unicode = "🇬🇷", tags = [], x = 1104, y = 46 }
        , { name = "greenland", unicode = "🇬🇱", tags = [], x = 1104, y = 276 }
        , { name = "grenada", unicode = "🇬🇩", tags = [], x = 1104, y = 322 }
        , { name = "guadeloupe", unicode = "🇬🇵", tags = [], x = 1104, y = 598 }
        , { name = "guam", unicode = "🇬🇺", tags = [], x = 1104, y = 644 }
        , { name = "guatemala", unicode = "🇬🇹", tags = [], x = 1104, y = 782 }
        , { name = "guernsey", unicode = "🇬🇬", tags = [], x = 1104, y = 828 }
        , { name = "guinea", unicode = "🇬🇳", tags = [], x = 1104, y = 874 }
        , { name = "guinea_bissau", unicode = "🇬🇼", tags = [], x = 1104, y = 920 }
        , { name = "guyana", unicode = "🇬🇾", tags = [], x = 1104, y = 1058 }
        , { name = "haiti", unicode = "🇭🇹", tags = [], x = 138, y = 1104 }
        , { name = "honduras", unicode = "🇭🇳", tags = [], x = 1150, y = 690 }
        , { name = "hong_kong", unicode = "🇭🇰", tags = [], x = 1150, y = 828 }
        , { name = "hungary", unicode = "🇭🇺", tags = [], x = 322, y = 1150 }
        , { name = "iceland", unicode = "🇮🇸", tags = [], x = 644, y = 1150 }
        , { name = "india", unicode = "🇮🇳", tags = [], x = 920, y = 1150 }
        , { name = "indonesia", unicode = "🇮🇩", tags = [], x = 966, y = 1150 }
        , { name = "iran", unicode = "🇮🇷", tags = [], x = 1196, y = 46 }
        , { name = "iraq", unicode = "🇮🇶", tags = [], x = 1196, y = 92 }
        , { name = "ireland", unicode = "🇮🇪", tags = [], x = 1196, y = 138 }
        , { name = "isle_of_man", unicode = "🇮🇲", tags = [], x = 1196, y = 184 }
        , { name = "israel", unicode = "🇮🇱", tags = [], x = 1196, y = 230 }
        , { name = "it", unicode = "🇮🇹", tags = [ "italy" ], x = 1196, y = 276 }
        , { name = "jamaica", unicode = "🇯🇲", tags = [], x = 1196, y = 414 }
        , { name = "jp", unicode = "🇯🇵", tags = [ "japan" ], x = 1196, y = 920 }
        , { name = "crossed_flags", unicode = "🎌", tags = [], x = 276, y = 828 }
        , { name = "jersey", unicode = "🇯🇪", tags = [], x = 1196, y = 690 }
        , { name = "jordan", unicode = "🇯🇴", tags = [], x = 1196, y = 736 }
        , { name = "kazakhstan", unicode = "🇰🇿", tags = [], x = 1196, y = 1012 }
        , { name = "kenya", unicode = "🇰🇪", tags = [], x = 1196, y = 1058 }
        , { name = "kiribati", unicode = "🇰🇮", tags = [], x = 138, y = 1196 }
        , { name = "kosovo", unicode = "🇽🇰", tags = [], x = 644, y = 1196 }
        , { name = "kuwait", unicode = "🇰🇼", tags = [], x = 736, y = 1196 }
        , { name = "kyrgyzstan", unicode = "🇰🇬", tags = [], x = 782, y = 1196 }
        , { name = "laos", unicode = "🇱🇦", tags = [], x = 920, y = 1196 }
        , { name = "latvia", unicode = "🇱🇻", tags = [], x = 1242, y = 0 }
        , { name = "lebanon", unicode = "🇱🇧", tags = [], x = 1242, y = 138 }
        , { name = "lesotho", unicode = "🇱🇸", tags = [], x = 1242, y = 506 }
        , { name = "liberia", unicode = "🇱🇷", tags = [], x = 1242, y = 598 }
        , { name = "libya", unicode = "🇱🇾", tags = [], x = 1242, y = 690 }
        , { name = "liechtenstein", unicode = "🇱🇮", tags = [], x = 1242, y = 736 }
        , { name = "lithuania", unicode = "🇱🇹", tags = [], x = 1242, y = 1012 }
        , { name = "luxembourg", unicode = "🇱🇺", tags = [], x = 276, y = 1242 }
        , { name = "macau", unicode = "🇲🇴", tags = [], x = 414, y = 1242 }
        , { name = "macedonia", unicode = "🇲🇰", tags = [], x = 460, y = 1242 }
        , { name = "madagascar", unicode = "🇲🇬", tags = [], x = 506, y = 1242 }
        , { name = "malawi", unicode = "🇲🇼", tags = [], x = 874, y = 1242 }
        , { name = "malaysia", unicode = "🇲🇾", tags = [], x = 920, y = 1242 }
        , { name = "maldives", unicode = "🇲🇻", tags = [], x = 966, y = 1242 }
        , { name = "mali", unicode = "🇲🇱", tags = [], x = 1058, y = 1242 }
        , { name = "malta", unicode = "🇲🇹", tags = [], x = 1104, y = 1242 }
        , { name = "marshall_islands", unicode = "🇲🇭", tags = [], x = 0, y = 1288 }
        , { name = "martinique", unicode = "🇲🇶", tags = [], x = 92, y = 1288 }
        , { name = "mauritania", unicode = "🇲🇷", tags = [], x = 322, y = 1288 }
        , { name = "mauritius", unicode = "🇲🇺", tags = [], x = 368, y = 1288 }
        , { name = "mayotte", unicode = "🇾🇹", tags = [], x = 0, y = 0 }
        , { name = "mexico", unicode = "🇲🇽", tags = [], x = 966, y = 1288 }
        , { name = "micronesia", unicode = "🇫🇲", tags = [], x = 1012, y = 1288 }
        , { name = "moldova", unicode = "🇲🇩", tags = [], x = 1334, y = 92 }
        , { name = "monaco", unicode = "🇲🇨", tags = [], x = 1334, y = 138 }
        , { name = "mongolia", unicode = "🇲🇳", tags = [], x = 1334, y = 322 }
        , { name = "montenegro", unicode = "🇲🇪", tags = [], x = 1334, y = 506 }
        , { name = "montserrat", unicode = "🇲🇸", tags = [], x = 1334, y = 552 }
        , { name = "morocco", unicode = "🇲🇦", tags = [], x = 1334, y = 644 }
        , { name = "mozambique", unicode = "🇲🇿", tags = [], x = 184, y = 1334 }
        , { name = "myanmar", unicode = "🇲🇲", tags = [ "burma" ], x = 552, y = 1334 }
        , { name = "namibia", unicode = "🇳🇦", tags = [], x = 690, y = 1334 }
        , { name = "nauru", unicode = "🇳🇷", tags = [], x = 782, y = 1334 }
        , { name = "nepal", unicode = "🇳🇵", tags = [], x = 1012, y = 1334 }
        , { name = "netherlands", unicode = "🇳🇱", tags = [], x = 1104, y = 1334 }
        , { name = "new_caledonia", unicode = "🇳🇨", tags = [], x = 1242, y = 1334 }
        , { name = "new_zealand", unicode = "🇳🇿", tags = [], x = 1380, y = 0 }
        , { name = "nicaragua", unicode = "🇳🇮", tags = [], x = 1380, y = 322 }
        , { name = "niger", unicode = "🇳🇪", tags = [], x = 1380, y = 368 }
        , { name = "nigeria", unicode = "🇳🇬", tags = [], x = 1380, y = 414 }
        , { name = "niue", unicode = "🇳🇺", tags = [], x = 1380, y = 552 }
        , { name = "norfolk_island", unicode = "🇳🇫", tags = [], x = 1380, y = 1150 }
        , { name = "northern_mariana_islands", unicode = "🇲🇵", tags = [], x = 1380, y = 1242 }
        , { name = "north_korea", unicode = "🇰🇵", tags = [], x = 1380, y = 1196 }
        , { name = "norway", unicode = "🇳🇴", tags = [], x = 1380, y = 1288 }
        , { name = "oman", unicode = "🇴🇲", tags = [], x = 920, y = 1380 }
        , { name = "pakistan", unicode = "🇵🇰", tags = [], x = 1426, y = 598 }
        , { name = "palau", unicode = "🇵🇼", tags = [], x = 1426, y = 644 }
        , { name = "palestinian_territories", unicode = "🇵🇸", tags = [], x = 1426, y = 690 }
        , { name = "panama", unicode = "🇵🇦", tags = [], x = 1426, y = 782 }
        , { name = "papua_new_guinea", unicode = "🇵🇬", tags = [], x = 1426, y = 1012 }
        , { name = "paraguay", unicode = "🇵🇾", tags = [], x = 1426, y = 1058 }
        , { name = "peru", unicode = "🇵🇪", tags = [], x = 736, y = 1426 }
        , { name = "philippines", unicode = "🇵🇭", tags = [], x = 782, y = 1426 }
        , { name = "pitcairn_islands", unicode = "🇵🇳", tags = [], x = 1242, y = 1426 }
        , { name = "poland", unicode = "🇵🇱", tags = [], x = 1472, y = 230 }
        , { name = "portugal", unicode = "🇵🇹", tags = [], x = 1472, y = 552 }
        , { name = "puerto_rico", unicode = "🇵🇷", tags = [], x = 0, y = 1472 }
        , { name = "qatar", unicode = "🇶🇦", tags = [], x = 276, y = 1472 }
        , { name = "reunion", unicode = "🇷🇪", tags = [], x = 1518, y = 598 }
        , { name = "romania", unicode = "🇷🇴", tags = [], x = 1518, y = 1334 }
        , { name = "ru", unicode = "🇷🇺", tags = [ "russia" ], x = 230, y = 1518 }
        , { name = "rwanda", unicode = "🇷🇼", tags = [], x = 552, y = 1518 }
        , { name = "st_barthelemy", unicode = "🇧🇱", tags = [], x = 1610, y = 1150 }
        , { name = "st_helena", unicode = "🇸🇭", tags = [], x = 1610, y = 1196 }
        , { name = "st_kitts_nevis", unicode = "🇰🇳", tags = [], x = 1610, y = 1242 }
        , { name = "st_lucia", unicode = "🇱🇨", tags = [], x = 1610, y = 1288 }
        , { name = "st_pierre_miquelon", unicode = "🇵🇲", tags = [], x = 1610, y = 1334 }
        , { name = "st_vincent_grenadines", unicode = "🇻🇨", tags = [], x = 1610, y = 1380 }
        , { name = "samoa", unicode = "🇼🇸", tags = [], x = 782, y = 1518 }
        , { name = "san_marino", unicode = "🇸🇲", tags = [], x = 828, y = 1518 }
        , { name = "sao_tome_principe", unicode = "🇸🇹", tags = [], x = 966, y = 1518 }
        , { name = "saudi_arabia", unicode = "🇸🇦", tags = [], x = 1104, y = 1518 }
        , { name = "senegal", unicode = "🇸🇳", tags = [], x = 1564, y = 230 }
        , { name = "serbia", unicode = "🇷🇸", tags = [], x = 1564, y = 276 }
        , { name = "seychelles", unicode = "🇸🇨", tags = [], x = 1564, y = 368 }
        , { name = "sierra_leone", unicode = "🇸🇱", tags = [], x = 1564, y = 1196 }
        , { name = "singapore", unicode = "🇸🇬", tags = [], x = 1564, y = 1288 }
        , { name = "sint_maarten", unicode = "🇸🇽", tags = [], x = 1564, y = 1334 }
        , { name = "slovakia", unicode = "🇸🇰", tags = [], x = 368, y = 1564 }
        , { name = "slovenia", unicode = "🇸🇮", tags = [], x = 414, y = 1564 }
        , { name = "solomon_islands", unicode = "🇸🇧", tags = [], x = 1472, y = 1564 }
        , { name = "somalia", unicode = "🇸🇴", tags = [], x = 1518, y = 1564 }
        , { name = "south_africa", unicode = "🇿🇦", tags = [], x = 1610, y = 92 }
        , { name = "south_georgia_south_sandwich_islands", unicode = "🇬🇸", tags = [], x = 1610, y = 138 }
        , { name = "kr", unicode = "🇰🇷", tags = [ "korea" ], x = 690, y = 1196 }
        , { name = "south_sudan", unicode = "🇸🇸", tags = [], x = 1610, y = 184 }
        , { name = "es", unicode = "🇪🇸", tags = [ "spain" ], x = 782, y = 920 }
        , { name = "sri_lanka", unicode = "🇱🇰", tags = [], x = 1610, y = 1104 }
        , { name = "sudan", unicode = "🇸🇩", tags = [], x = 736, y = 1610 }
        , { name = "suriname", unicode = "🇸🇷", tags = [], x = 1334, y = 1610 }
        , { name = "swaziland", unicode = "🇸🇿", tags = [], x = 1518, y = 1610 }
        , { name = "sweden", unicode = "🇸🇪", tags = [], x = 1656, y = 46 }
        , { name = "switzerland", unicode = "🇨🇭", tags = [], x = 1656, y = 276 }
        , { name = "syria", unicode = "🇸🇾", tags = [], x = 1656, y = 414 }
        , { name = "taiwan", unicode = "🇹🇼", tags = [], x = 1656, y = 598 }
        , { name = "tajikistan", unicode = "🇹🇯", tags = [], x = 1656, y = 644 }
        , { name = "tanzania", unicode = "🇹🇿", tags = [], x = 1656, y = 782 }
        , { name = "thailand", unicode = "🇹🇭", tags = [], x = 1656, y = 1196 }
        , { name = "timor_leste", unicode = "🇹🇱", tags = [], x = 92, y = 1656 }
        , { name = "togo", unicode = "🇹🇬", tags = [], x = 322, y = 1656 }
        , { name = "tokelau", unicode = "🇹🇰", tags = [], x = 414, y = 1656 }
        , { name = "tonga", unicode = "🇹🇴", tags = [], x = 552, y = 1656 }
        , { name = "trinidad_tobago", unicode = "🇹🇹", tags = [], x = 1242, y = 1656 }
        , { name = "tunisia", unicode = "🇹🇳", tags = [], x = 1702, y = 92 }
        , { name = "tr", unicode = "🇹🇷", tags = [ "turkey" ], x = 782, y = 1656 }
        , { name = "turkmenistan", unicode = "🇹🇲", tags = [], x = 1702, y = 184 }
        , { name = "turks_caicos_islands", unicode = "🇹🇨", tags = [], x = 1702, y = 230 }
        , { name = "tuvalu", unicode = "🇹🇻", tags = [], x = 1702, y = 322 }
        , { name = "uganda", unicode = "🇺🇬", tags = [], x = 1702, y = 1150 }
        , { name = "ukraine", unicode = "🇺🇦", tags = [], x = 1702, y = 1242 }
        , { name = "united_arab_emirates", unicode = "🇦🇪", tags = [], x = 1702, y = 1472 }
        , { name = "gb", unicode = "🇬🇧", tags = [ "flag", "british" ], x = 184, y = 1058 }
        , { name = "us", unicode = "🇺🇸", tags = [ "flag", "united", "america" ], x = 0, y = 1702 }
        , { name = "us_virgin_islands", unicode = "🇻🇮", tags = [], x = 46, y = 1702 }
        , { name = "uruguay", unicode = "🇺🇾", tags = [], x = 1702, y = 1656 }
        , { name = "uzbekistan", unicode = "🇺🇿", tags = [], x = 92, y = 1702 }
        , { name = "vanuatu", unicode = "🇻🇺", tags = [], x = 184, y = 1702 }
        , { name = "vatican_city", unicode = "🇻🇦", tags = [], x = 230, y = 1702 }
        , { name = "venezuela", unicode = "🇻🇪", tags = [], x = 276, y = 1702 }
        , { name = "vietnam", unicode = "🇻🇳", tags = [], x = 552, y = 1702 }
        , { name = "wallis_futuna", unicode = "🇼🇫", tags = [], x = 1012, y = 1702 }
        , { name = "western_sahara", unicode = "🇪🇭", tags = [], x = 1748, y = 46 }
        , { name = "yemen", unicode = "🇾🇪", tags = [], x = 782, y = 1748 }
        , { name = "zambia", unicode = "🇿🇲", tags = [], x = 966, y = 1748 }
        , { name = "zimbabwe", unicode = "🇿🇼", tags = [], x = 1104, y = 1748 }
        ]
    , symbols =
        [ { name = "heart", unicode = "❤️", tags = [ "love" ], x = 828, y = 1104 }
        , { name = "yellow_heart", unicode = "💛", tags = [], x = 736, y = 1748 }
        , { name = "green_heart", unicode = "💚", tags = [], x = 1104, y = 184 }
        , { name = "blue_heart", unicode = "💙", tags = [], x = 552, y = 276 }
        , { name = "purple_heart", unicode = "💜", tags = [], x = 92, y = 1472 }
        , { name = "black_heart", unicode = "🖤", tags = [], x = 184, y = 506 }
        , { name = "broken_heart", unicode = "💔", tags = [], x = 598, y = 506 }
        , { name = "heavy_heart_exclamation", unicode = "❣️", tags = [], x = 1150, y = 184 }
        , { name = "two_hearts", unicode = "💕", tags = [], x = 1702, y = 506 }
        , { name = "revolving_hearts", unicode = "💞", tags = [], x = 1518, y = 644 }
        , { name = "heartbeat", unicode = "💓", tags = [], x = 1012, y = 1104 }
        , { name = "heartpulse", unicode = "💗", tags = [], x = 1058, y = 1104 }
        , { name = "sparkling_heart", unicode = "💖", tags = [], x = 1610, y = 506 }
        , { name = "cupid", unicode = "💘", tags = [ "love", "heart" ], x = 644, y = 828 }
        , { name = "gift_heart", unicode = "💝", tags = [ "chocolates" ], x = 598, y = 1058 }
        , { name = "heart_decoration", unicode = "💟", tags = [], x = 874, y = 1104 }
        , { name = "peace_symbol", unicode = "☮️", tags = [], x = 46, y = 1426 }
        , { name = "latin_cross", unicode = "✝️", tags = [], x = 1196, y = 1196 }
        , { name = "star_and_crescent", unicode = "☪️", tags = [], x = 1610, y = 1564 }
        , { name = "om", unicode = "🕉", tags = [], x = 874, y = 1380 }
        , { name = "wheel_of_dharma", unicode = "☸️", tags = [], x = 1748, y = 184 }
        , { name = "star_of_david", unicode = "✡️", tags = [], x = 0, y = 1610 }
        , { name = "six_pointed_star", unicode = "🔯", tags = [], x = 1564, y = 1426 }
        , { name = "menorah", unicode = "🕎", tags = [], x = 782, y = 1288 }
        , { name = "yin_yang", unicode = "☯️", tags = [], x = 874, y = 1748 }
        , { name = "orthodox_cross", unicode = "☦️", tags = [], x = 1426, y = 184 }
        , { name = "place_of_worship", unicode = "🛐", tags = [], x = 1334, y = 1426 }
        , { name = "ophiuchus", unicode = "⛎", tags = [], x = 1426, y = 46 }
        , { name = "aries", unicode = "♈️", tags = [], x = 276, y = 138 }
        , { name = "taurus", unicode = "♉️", tags = [], x = 1656, y = 828 }
        , { name = "gemini", unicode = "♊️", tags = [], x = 322, y = 1058 }
        , { name = "cancer", unicode = "♋️", tags = [], x = 0, y = 644 }
        , { name = "leo", unicode = "♌️", tags = [], x = 1242, y = 414 }
        , { name = "virgo", unicode = "♍️", tags = [], x = 644, y = 1702 }
        , { name = "libra", unicode = "♎️", tags = [], x = 1242, y = 644 }
        , { name = "scorpius", unicode = "♏️", tags = [], x = 1380, y = 1518 }
        , { name = "sagittarius", unicode = "♐️", tags = [], x = 644, y = 1518 }
        , { name = "capricorn", unicode = "♑️", tags = [], x = 276, y = 644 }
        , { name = "aquarius", unicode = "♒️", tags = [], x = 276, y = 46 }
        , { name = "pisces", unicode = "♓️", tags = [], x = 1196, y = 1426 }
        , { name = "id", unicode = "🆔", tags = [], x = 690, y = 1150 }
        , { name = "atom_symbol", unicode = "⚛️", tags = [], x = 368, y = 276 }
        , { name = "accept", unicode = "🉑", tags = [], x = 0, y = 138 }
        , { name = "radioactive", unicode = "☢️", tags = [], x = 644, y = 1472 }
        , { name = "biohazard", unicode = "☣️", tags = [], x = 506, y = 460 }
        , { name = "mobile_phone_off", unicode = "📴", tags = [ "mute", "off" ], x = 1334, y = 46 }
        , { name = "vibration_mode", unicode = "📳", tags = [], x = 414, y = 1702 }
        , { name = "u6709", unicode = "🈶", tags = [], x = 1702, y = 874 }
        , { name = "u7121", unicode = "🈚️", tags = [], x = 1702, y = 966 }
        , { name = "u7533", unicode = "🈸", tags = [], x = 1702, y = 1012 }
        , { name = "u55b6", unicode = "🈺", tags = [], x = 1702, y = 736 }
        , { name = "u6708", unicode = "🈷️", tags = [], x = 1702, y = 828 }
        , { name = "eight_pointed_black_star", unicode = "✴️", tags = [], x = 230, y = 920 }
        , { name = "vs", unicode = "🆚", tags = [], x = 782, y = 1702 }
        , { name = "white_flower", unicode = "💮", tags = [], x = 1748, y = 414 }
        , { name = "ideograph_advantage", unicode = "🉐", tags = [], x = 736, y = 1150 }
        , { name = "secret", unicode = "㊙️", tags = [], x = 1564, y = 46 }
        , { name = "congratulations", unicode = "㊗️", tags = [], x = 230, y = 782 }
        , { name = "u5408", unicode = "🈴", tags = [], x = 1702, y = 690 }
        , { name = "u6e80", unicode = "🈵", tags = [], x = 1702, y = 920 }
        , { name = "u5272", unicode = "🈹", tags = [], x = 1702, y = 644 }
        , { name = "u7981", unicode = "🈲", tags = [], x = 1702, y = 1058 }
        , { name = "a", unicode = "🅰️", tags = [], x = 92, y = 92 }
        , { name = "b", unicode = "🅱️", tags = [], x = 138, y = 368 }
        , { name = "ab", unicode = "🆎", tags = [], x = 138, y = 0 }
        , { name = "cl", unicode = "🆑", tags = [], x = 598, y = 690 }
        , { name = "o2", unicode = "🅾️", tags = [], x = 230, y = 1380 }
        , { name = "sos", unicode = "🆘", tags = [ "help", "emergency" ], x = 1610, y = 0 }
        , { name = "x", unicode = "❌", tags = [], x = 690, y = 1748 }
        , { name = "o", unicode = "⭕️", tags = [], x = 184, y = 1380 }
        , { name = "stop_sign", unicode = "🛑", tags = [], x = 322, y = 1610 }
        , { name = "no_entry", unicode = "⛔️", tags = [ "limit" ], x = 1380, y = 690 }
        , { name = "name_badge", unicode = "📛", tags = [], x = 644, y = 1334 }
        , { name = "no_entry_sign", unicode = "🚫", tags = [ "block", "forbidden" ], x = 1380, y = 736 }
        , { name = "100", unicode = "💯", tags = [ "score", "perfect" ], x = 0, y = 46 }
        , { name = "anger", unicode = "💢", tags = [ "angry" ], x = 230, y = 138 }
        , { name = "hotsprings", unicode = "♨️", tags = [], x = 0, y = 1150 }
        , { name = "no_pedestrians", unicode = "🚷", tags = [], x = 1380, y = 1012 }
        , { name = "do_not_litter", unicode = "🚯", tags = [], x = 598, y = 874 }
        , { name = "no_bicycles", unicode = "🚳", tags = [], x = 1380, y = 644 }
        , { name = "non-potable_water", unicode = "🚱", tags = [], x = 1380, y = 1104 }
        , { name = "underage", unicode = "🔞", tags = [], x = 1702, y = 1380 }
        , { name = "no_mobile_phones", unicode = "📵", tags = [], x = 1380, y = 920 }
        , { name = "no_smoking", unicode = "🚭", tags = [], x = 1380, y = 1058 }
        , { name = "exclamation", unicode = "❗️", tags = [ "bang" ], x = 966, y = 230 }
        , { name = "grey_exclamation", unicode = "❕", tags = [], x = 1104, y = 368 }
        , { name = "question", unicode = "❓", tags = [ "confused" ], x = 322, y = 1472 }
        , { name = "grey_question", unicode = "❔", tags = [], x = 1104, y = 414 }
        , { name = "bangbang", unicode = "‼️", tags = [], x = 138, y = 414 }
        , { name = "interrobang", unicode = "⁉️", tags = [], x = 1150, y = 1150 }
        , { name = "low_brightness", unicode = "🔅", tags = [], x = 230, y = 1242 }
        , { name = "high_brightness", unicode = "🔆", tags = [], x = 1150, y = 506 }
        , { name = "part_alternation_mark", unicode = "〽️", tags = [], x = 1426, y = 1196 }
        , { name = "warning", unicode = "⚠️", tags = [ "wip" ], x = 1150, y = 1702 }
        , { name = "children_crossing", unicode = "🚸", tags = [], x = 46, y = 690 }
        , { name = "trident", unicode = "🔱", tags = [], x = 1196, y = 1656 }
        , { name = "fleur_de_lis", unicode = "⚜️", tags = [], x = 506, y = 1012 }
        , { name = "beginner", unicode = "🔰", tags = [], x = 276, y = 460 }
        , { name = "recycle", unicode = "♻️", tags = [ "environment", "green" ], x = 1518, y = 92 }
        , { name = "white_check_mark", unicode = "✅", tags = [], x = 1748, y = 276 }
        , { name = "u6307", unicode = "🈯️", tags = [], x = 1702, y = 782 }
        , { name = "chart", unicode = "💹", tags = [], x = 690, y = 322 }
        , { name = "sparkle", unicode = "❇️", tags = [], x = 1610, y = 368 }
        , { name = "eight_spoked_asterisk", unicode = "✳️", tags = [], x = 276, y = 920 }
        , { name = "negative_squared_cross_mark", unicode = "❎", tags = [], x = 966, y = 1334 }
        , { name = "globe_with_meridians", unicode = "🌐", tags = [ "world", "global", "international" ], x = 690, y = 1058 }
        , { name = "diamond_shape_with_a_dot_inside", unicode = "💠", tags = [], x = 276, y = 874 }
        , { name = "m", unicode = "Ⓜ️", tags = [], x = 368, y = 1242 }
        , { name = "cyclone", unicode = "🌀", tags = [ "swirl" ], x = 874, y = 92 }
        , { name = "zzz", unicode = "💤", tags = [ "sleeping" ], x = 1196, y = 1748 }
        , { name = "atm", unicode = "🏧", tags = [], x = 368, y = 184 }
        , { name = "wc", unicode = "🚾", tags = [ "toilet", "restroom" ], x = 1564, y = 1702 }
        , { name = "wheelchair", unicode = "♿️", tags = [ "accessibility" ], x = 1748, y = 230 }
        , { name = "parking", unicode = "🅿️", tags = [], x = 1426, y = 1150 }
        , { name = "u7a7a", unicode = "🈳", tags = [], x = 1702, y = 1104 }
        , { name = "sa", unicode = "🈂️", tags = [], x = 598, y = 1518 }
        , { name = "passport_control", unicode = "🛂", tags = [], x = 1426, y = 1334 }
        , { name = "customs", unicode = "🛃", tags = [], x = 874, y = 46 }
        , { name = "baggage_claim", unicode = "🛄", tags = [ "airport" ], x = 414, y = 92 }
        , { name = "left_luggage", unicode = "🛅", tags = [], x = 1242, y = 230 }
        , { name = "mens", unicode = "🚹", tags = [], x = 828, y = 1288 }
        , { name = "womens", unicode = "🚺", tags = [], x = 460, y = 1748 }
        , { name = "baby_symbol", unicode = "🚼", tags = [], x = 322, y = 368 }
        , { name = "restroom", unicode = "🚻", tags = [ "toilet" ], x = 1518, y = 552 }
        , { name = "put_litter_in_its_place", unicode = "🚮", tags = [], x = 230, y = 1472 }
        , { name = "cinema", unicode = "🎦", tags = [ "film", "movie" ], x = 368, y = 690 }
        , { name = "signal_strength", unicode = "📶", tags = [ "wifi" ], x = 1564, y = 1242 }
        , { name = "koko", unicode = "🈁", tags = [], x = 598, y = 1196 }
        , { name = "symbols", unicode = "🔣", tags = [], x = 1656, y = 322 }
        , { name = "information_source", unicode = "ℹ️", tags = [], x = 1058, y = 1150 }
        , { name = "abc", unicode = "🔤", tags = [ "alphabet" ], x = 138, y = 46 }
        , { name = "abcd", unicode = "🔡", tags = [], x = 138, y = 92 }
        , { name = "capital_abcd", unicode = "🔠", tags = [ "letters" ], x = 230, y = 644 }
        , { name = "ng", unicode = "🆖", tags = [], x = 1380, y = 184 }
        , { name = "ok", unicode = "🆗", tags = [ "yes" ], x = 552, y = 1380 }
        , { name = "up", unicode = "🆙", tags = [], x = 1702, y = 1564 }
        , { name = "cool", unicode = "🆒", tags = [], x = 644, y = 782 }
        , { name = "new", unicode = "🆕", tags = [ "fresh" ], x = 1196, y = 1334 }
        , { name = "free", unicode = "🆓", tags = [], x = 1058, y = 322 }
        , { name = "zero", unicode = "0️⃣", tags = [], x = 1058, y = 1748 }
        , { name = "one", unicode = "1️⃣", tags = [], x = 1196, y = 1380 }
        , { name = "two", unicode = "2️⃣", tags = [], x = 1702, y = 460 }
        , { name = "three", unicode = "3️⃣", tags = [], x = 1656, y = 1380 }
        , { name = "four", unicode = "4️⃣", tags = [], x = 1058, y = 92 }
        , { name = "five", unicode = "5️⃣", tags = [], x = 368, y = 1012 }
        , { name = "six", unicode = "6️⃣", tags = [], x = 1564, y = 1380 }
        , { name = "seven", unicode = "7️⃣", tags = [], x = 1564, y = 322 }
        , { name = "eight", unicode = "8️⃣", tags = [], x = 184, y = 920 }
        , { name = "nine", unicode = "9️⃣", tags = [], x = 1380, y = 506 }
        , { name = "keycap_ten", unicode = "🔟", tags = [], x = 0, y = 1196 }
        , { name = "1234", unicode = "🔢", tags = [ "numbers" ], x = 46, y = 46 }
        , { name = "hash", unicode = "#️⃣", tags = [ "number" ], x = 598, y = 1104 }
        , { name = "asterisk", unicode = "*️⃣", tags = [], x = 368, y = 46 }
        , { name = "arrow_forward", unicode = "▶️", tags = [], x = 184, y = 276 }
        , { name = "pause_button", unicode = "⏸", tags = [], x = 1426, y = 1380 }
        , { name = "play_or_pause_button", unicode = "⏯", tags = [], x = 1426, y = 1426 }
        , { name = "stop_button", unicode = "⏹", tags = [], x = 276, y = 1610 }
        , { name = "record_button", unicode = "⏺", tags = [], x = 1518, y = 46 }
        , { name = "next_track_button", unicode = "⏭", tags = [], x = 1380, y = 138 }
        , { name = "previous_track_button", unicode = "⏮", tags = [], x = 1472, y = 1288 }
        , { name = "fast_forward", unicode = "⏩", tags = [], x = 1012, y = 46 }
        , { name = "rewind", unicode = "⏪", tags = [], x = 1518, y = 690 }
        , { name = "arrow_double_up", unicode = "⏫", tags = [], x = 46, y = 276 }
        , { name = "arrow_double_down", unicode = "⏬", tags = [], x = 0, y = 276 }
        , { name = "arrow_backward", unicode = "◀️", tags = [], x = 276, y = 230 }
        , { name = "arrow_up_small", unicode = "🔼", tags = [], x = 0, y = 322 }
        , { name = "arrow_down_small", unicode = "🔽", tags = [], x = 138, y = 276 }
        , { name = "arrow_right", unicode = "➡️", tags = [], x = 322, y = 138 }
        , { name = "arrow_left", unicode = "⬅️", tags = [], x = 322, y = 0 }
        , { name = "arrow_up", unicode = "⬆️", tags = [], x = 322, y = 230 }
        , { name = "arrow_down", unicode = "⬇️", tags = [], x = 92, y = 276 }
        , { name = "arrow_upper_right", unicode = "↗️", tags = [], x = 92, y = 322 }
        , { name = "arrow_lower_right", unicode = "↘️", tags = [], x = 322, y = 92 }
        , { name = "arrow_lower_left", unicode = "↙️", tags = [], x = 322, y = 46 }
        , { name = "arrow_upper_left", unicode = "↖️", tags = [], x = 46, y = 322 }
        , { name = "arrow_up_down", unicode = "↕️", tags = [], x = 322, y = 276 }
        , { name = "left_right_arrow", unicode = "↔️", tags = [], x = 1242, y = 276 }
        , { name = "arrow_right_hook", unicode = "↪️", tags = [], x = 322, y = 184 }
        , { name = "leftwards_arrow_with_hook", unicode = "↩️", tags = [ "return" ], x = 1242, y = 322 }
        , { name = "arrow_heading_up", unicode = "⤴️", tags = [], x = 276, y = 276 }
        , { name = "arrow_heading_down", unicode = "⤵️", tags = [], x = 230, y = 276 }
        , { name = "twisted_rightwards_arrows", unicode = "🔀", tags = [ "shuffle" ], x = 1702, y = 414 }
        , { name = "repeat", unicode = "🔁", tags = [ "loop" ], x = 1518, y = 414 }
        , { name = "repeat_one", unicode = "🔂", tags = [], x = 1518, y = 460 }
        , { name = "arrows_counterclockwise", unicode = "🔄", tags = [ "sync" ], x = 184, y = 322 }
        , { name = "arrows_clockwise", unicode = "🔃", tags = [], x = 138, y = 322 }
        , { name = "musical_note", unicode = "🎵", tags = [], x = 414, y = 1334 }
        , { name = "notes", unicode = "🎶", tags = [ "music" ], x = 92, y = 1380 }
        , { name = "heavy_plus_sign", unicode = "➕", tags = [], x = 1150, y = 322 }
        , { name = "heavy_minus_sign", unicode = "➖", tags = [], x = 1150, y = 230 }
        , { name = "heavy_division_sign", unicode = "➗", tags = [], x = 1150, y = 46 }
        , { name = "heavy_multiplication_x", unicode = "✖️", tags = [], x = 1150, y = 276 }
        , { name = "heavy_dollar_sign", unicode = "💲", tags = [], x = 1150, y = 92 }
        , { name = "currency_exchange", unicode = "💱", tags = [], x = 782, y = 828 }
        , { name = "tm", unicode = "™️", tags = [ "trademark" ], x = 276, y = 1656 }
        , { name = "copyright", unicode = "©️", tags = [], x = 736, y = 782 }
        , { name = "registered", unicode = "®️", tags = [], x = 1518, y = 230 }
        , { name = "wavy_dash", unicode = "〰️", tags = [], x = 1426, y = 1702 }
        , { name = "curly_loop", unicode = "➰", tags = [], x = 736, y = 828 }
        , { name = "loop", unicode = "➿", tags = [], x = 0, y = 1242 }
        , { name = "end", unicode = "🔚", tags = [], x = 552, y = 920 }
        , { name = "back", unicode = "🔙", tags = [], x = 368, y = 368 }
        , { name = "on", unicode = "🔛", tags = [], x = 966, y = 1380 }
        , { name = "top", unicode = "🔝", tags = [], x = 644, y = 1656 }
        , { name = "soon", unicode = "🔜", tags = [], x = 1564, y = 1564 }
        , { name = "heavy_check_mark", unicode = "✔️", tags = [], x = 1150, y = 0 }
        , { name = "ballot_box_with_check", unicode = "☑️", tags = [], x = 0, y = 414 }
        , { name = "radio_button", unicode = "🔘", tags = [], x = 598, y = 1472 }
        , { name = "white_circle", unicode = "⚪️", tags = [], x = 1748, y = 322 }
        , { name = "black_circle", unicode = "⚫️", tags = [], x = 92, y = 506 }
        , { name = "red_circle", unicode = "🔴", tags = [], x = 1518, y = 184 }
        , { name = "large_blue_circle", unicode = "🔵", tags = [], x = 966, y = 1196 }
        , { name = "small_red_triangle", unicode = "🔺", tags = [], x = 598, y = 1564 }
        , { name = "small_red_triangle_down", unicode = "🔻", tags = [], x = 644, y = 1564 }
        , { name = "small_orange_diamond", unicode = "🔸", tags = [], x = 552, y = 1564 }
        , { name = "small_blue_diamond", unicode = "🔹", tags = [], x = 506, y = 1564 }
        , { name = "large_orange_diamond", unicode = "🔶", tags = [], x = 1058, y = 1196 }
        , { name = "large_blue_diamond", unicode = "🔷", tags = [], x = 1012, y = 1196 }
        , { name = "white_square_button", unicode = "🔳", tags = [], x = 1748, y = 644 }
        , { name = "black_square_button", unicode = "🔲", tags = [], x = 506, y = 506 }
        , { name = "black_small_square", unicode = "▪️", tags = [], x = 460, y = 506 }
        , { name = "white_small_square", unicode = "▫️", tags = [], x = 1748, y = 598 }
        , { name = "black_medium_small_square", unicode = "◾️", tags = [], x = 322, y = 506 }
        , { name = "white_medium_small_square", unicode = "◽️", tags = [], x = 1748, y = 506 }
        , { name = "black_medium_square", unicode = "◼️", tags = [], x = 368, y = 506 }
        , { name = "white_medium_square", unicode = "◻️", tags = [], x = 1748, y = 552 }
        , { name = "black_large_square", unicode = "⬛️", tags = [], x = 276, y = 506 }
        , { name = "white_large_square", unicode = "⬜️", tags = [], x = 1748, y = 460 }
        , { name = "speaker", unicode = "🔈", tags = [], x = 1610, y = 598 }
        , { name = "mute", unicode = "🔇", tags = [ "sound", "volume" ], x = 506, y = 1334 }
        , { name = "sound", unicode = "🔉", tags = [ "volume" ], x = 1610, y = 46 }
        , { name = "loud_sound", unicode = "🔊", tags = [ "volume" ], x = 46, y = 1242 }
        , { name = "bell", unicode = "🔔", tags = [ "sound", "notification" ], x = 460, y = 460 }
        , { name = "no_bell", unicode = "🔕", tags = [ "volume", "off" ], x = 1380, y = 598 }
        , { name = "mega", unicode = "📣", tags = [], x = 598, y = 1288 }
        , { name = "loudspeaker", unicode = "📢", tags = [ "announcement" ], x = 92, y = 1242 }
        , { name = "eye_speech_bubble", unicode = "👁\u{200D}🗨️", tags = [], x = 966, y = 368 }
        , { name = "speech_balloon", unicode = "💬", tags = [ "comment" ], x = 1610, y = 690 }
        , { name = "thought_balloon", unicode = "💭", tags = [ "thinking" ], x = 1656, y = 1334 }
        , { name = "right_anger_bubble", unicode = "🗯", tags = [], x = 1518, y = 1012 }
        , { name = "spades", unicode = "♠️", tags = [], x = 1610, y = 276 }
        , { name = "clubs", unicode = "♣️", tags = [], x = 782, y = 184 }
        , { name = "hearts", unicode = "♥️", tags = [], x = 1104, y = 1104 }
        , { name = "diamonds", unicode = "♦️", tags = [], x = 322, y = 874 }
        , { name = "black_joker", unicode = "🃏", tags = [], x = 230, y = 506 }
        , { name = "flower_playing_cards", unicode = "🎴", tags = [], x = 736, y = 1012 }
        , { name = "mahjong", unicode = "🀄️", tags = [], x = 644, y = 1242 }
        , { name = "clock1", unicode = "🕐", tags = [], x = 736, y = 184 }
        , { name = "clock2", unicode = "🕑", tags = [], x = 736, y = 552 }
        , { name = "clock3", unicode = "🕒", tags = [], x = 736, y = 644 }
        , { name = "clock4", unicode = "🕓", tags = [], x = 0, y = 736 }
        , { name = "clock5", unicode = "🕔", tags = [], x = 92, y = 736 }
        , { name = "clock6", unicode = "🕕", tags = [], x = 184, y = 736 }
        , { name = "clock7", unicode = "🕖", tags = [], x = 276, y = 736 }
        , { name = "clock8", unicode = "🕗", tags = [], x = 368, y = 736 }
        , { name = "clock9", unicode = "🕘", tags = [], x = 460, y = 736 }
        , { name = "clock10", unicode = "🕙", tags = [], x = 736, y = 230 }
        , { name = "clock11", unicode = "🕚", tags = [], x = 736, y = 322 }
        , { name = "clock12", unicode = "🕛", tags = [], x = 736, y = 414 }
        , { name = "clock130", unicode = "🕜", tags = [], x = 736, y = 506 }
        , { name = "clock230", unicode = "🕝", tags = [], x = 736, y = 598 }
        , { name = "clock330", unicode = "🕞", tags = [], x = 736, y = 690 }
        , { name = "clock430", unicode = "🕟", tags = [], x = 46, y = 736 }
        , { name = "clock530", unicode = "🕠", tags = [], x = 138, y = 736 }
        , { name = "clock630", unicode = "🕡", tags = [], x = 230, y = 736 }
        , { name = "clock730", unicode = "🕢", tags = [], x = 322, y = 736 }
        , { name = "clock830", unicode = "🕣", tags = [], x = 414, y = 736 }
        , { name = "clock930", unicode = "🕤", tags = [], x = 506, y = 736 }
        , { name = "clock1030", unicode = "🕥", tags = [], x = 736, y = 276 }
        , { name = "clock1130", unicode = "🕦", tags = [], x = 736, y = 368 }
        , { name = "clock1230", unicode = "🕧", tags = [], x = 736, y = 460 }
        ]
    }
